from typing import Final

# Removed reseed functionality
from ..schema.nexusphp import Attendance


class MainClass(Attendance):
    URL: Final = 'https://hdfans.org/'
    USER_CLASSES: Final = {
        'downloaded': [4398046511104, 10995116277760],
        'share_ratio': [3.5, 5],
        'days': [210, 364]
    }



from typing import Final

from ..schema.xbtit import XBTIT
from ..utils import net_utils
from ..utils.value_handler import handle_infinite


class MainClass(XBTIT):
    URL: Final = 'https://gay-torrents.org/'
    SUCCEED_REGEX: Final = 'Logout'
    USER_CLASSES: Final = {
        'uploaded': [268435456000],
        'share_ratio': [2]
    }

    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        net_utils.dict_merge(selector, {
            'user_id': r'<li><a href="usercp\.php\?uid=(\d+)">My Panel</a>',
            'detail_sources': {
                'default': {
                    'link': '/usercp.php?uid={}',
                    'elements': {
                        'bar': '#user_info',
                        'table': '#main > section > div.block_content.news > section > div.block_content.news > table'
                    }
                }
            },
            'details': {
                'uploaded': {
                    'regex': r'Uploaded\s*([\d.]+ ([ZEPTGMK]i)?B)'
                },
                'downloaded': {
                    'regex': r'Downloaded\s*([\d.]+ ([ZEPTGMK]i)?B)'
                },
                'share_ratio': {
                    'regex': r'Ratio\s*(---|[\d.]+)',
                    'handle': handle_infinite
                },
                'points': {
                    'regex': r'Bonus: (---|[\d.]+)',
                    'handle': handle_infinite
                },
                'join_date': {
                    'regex': r'Joined on\s*(\d{2}/\d{2}/\d{4})',
                    'handle': self.handle_join_date
                },
                'seeding': {
                    'regex': r'Active:\s*(\d+)\s*/\s*\d+'
                },
                'leeching': {
                    'regex': r'Active:\s*\d+\s*/\s*(\d+)'
                },
                'hr': None
            }
        })
        return selector



import re
from abc import ABC

from .private_torrent import PrivateTorrent
from ..utils.net_utils import get_module_name
from ..utils.value_handler import handle_infinite, handle_join_date


class XBT(PrivateTorrent, ABC):
    @classmethod
    def sign_in_build_schema(cls) -> dict:
        return {
            get_module_name(cls): {
                'type': 'object',
                'properties': {
                    'login': {
                        'type': 'object',
                        'properties': {
                            'username': {'type': 'string'},
                            'password': {'type': 'string'}
                        },
                        'additionalProperties': False
                    }
                },
                'additionalProperties': False
            }
        }

    @property
    def details_selector(self) -> dict:
        return {
            'user_id': f'{re.escape("userdetails.php?id=")}'r"(\d+)'>Profile",
            'detail_sources': {
                'default': {
                    'link': '/userdetails.php?id={}',
                    'elements': {
                        'stats': '#slidingDiv',
                        'join date': '#general > table > tbody > tr:nth-child(1)'
                    }
                },
            },
            'details': {
                'uploaded': {
                    'regex': r'''(?x)Uploaded
                                    ([\d.] +
                                    ([ZEPTGMK] i) ? B)''',
                },
                'downloaded': {
                    'regex': r'''(?x)Downloaded
                                    ([\d.] +
                                    ([ZEPTGMK] i) ? B)''',
                },
                'share_ratio': {
                    'regex': r'''(?x)Share\ Ratio
                                    \s*
                                    (Inf | [\d,.] +)''',
                    'handle': handle_infinite
                },
                'points': {
                    'regex': r'''(?x)Bonus\ Points
                                    \s*
                                    ([\d,.] +)'''
                },
                'join_date': {
                    'regex': r'''(?x)Join date
                                    ((\w + \ ) {2} \w +)''',
                    'handle': handle_join_date
                },
                'seeding': {
                    'regex': r'''(?x)Seeding\ Torrents
                                    \s*
                                    ([\d,] +)'''
                },
                'leeching': {
                    'regex': r'''(?x)Leeching\ Torrents
                                    \s*
                                    ([\d,] +)'''
                },
                'hr': {
                    'regex': r'''(?x)Unsatisfied\ Torrents
                                    \s*
                                    ([\d,] +)'''
                }
            }
        }



from typing import Final

from ..core.entry import SignInEntry
from ..base.sign_in import check_final_state, SignState
from ..base.work import Work
from ..schema.unit3d import Unit3D
from ..utils import net_utils
from ..utils.value_handler import handle_join_date, size


class MainClass(Unit3D):
    URL: Final = 'https://monikadesign.uk/'
    USER_CLASSES: Final = {
        'uploaded': [size(15, 'TiB')],
        'days': [36500]
    }

    def sign_in_build_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/',
                method=self.sign_in_by_get,
                succeed_regex=[(r'<a href="https://monikadesign.uk/users/(.*?)/uploads', 1)],
                assert_state=(check_final_state, SignState.SUCCEED),
                is_base_content=True
            )
        ]

    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        net_utils.dict_merge(selector, {
            'user_id': '/users/(.*)/',
            'detail_sources': {
                'default': {
                    'do_not_strip': True,
                    'elements': {
                        'bar': '.top-nav__stats',
                        'ratio_bar': '.top-nav__ratio-bar',
                        'header': '.header',
                        'data_table': '.user-info'
                    }
                }
            },
            'details': {
                'leeching': {
                    'regex': (r'(下载).+?(\d+)', 2)
                },
                'points': {
                    'regex': 'title="魔力".*?</i>.+?(\\d[\\d,. ]*)',
                },
                'share_ratio': {
                    'regex': 'title="分享率".*?</i>.+?(\\d[\\d,. ]*)',
                },
                'join_date': {
                    'regex': '注册日期 (.*?\\d{4})',
                    'handle': handle_join_date
                },
                'hr': None
            }
        })
        return selector



from typing import Final

# Removed reseed functionality
from ..schema.nexusphp import Attendance
from ..utils import net_utils
from ..utils.value_handler import size


class MainClass(Attendance):
    URL: Final = 'https://kufei.org/'
    USER_CLASSES: Final = {
        'downloaded': [size(1.92, 'TiB'), size(10, 'TiB')],
        'share_ratio': [4, 6],
        'points': [1200000, 2000000],
        'days': [280, 700]
    }

    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        net_utils.dict_merge(selector, {
            'details': {
                'points': {
                    'regex': (r'(做种积分).*?([\d,.]+)', 2)
                },
            }
        })
        return selector



"""
签到条目类
移除FlexGet依赖的独立实现
"""
import json
import pathlib
from typing import Any, Dict


class SignInEntry:
    """签到条目类，替代FlexGet的Entry"""
    
    def __init__(self, title: str, url: str = ''):
        self.data: Dict[str, Any] = {
            'title': title,
            'url': url
        }
        self.failed = False
        self.reason = ''
    
    def __getitem__(self, key: str) -> Any:
        """获取条目属性"""
        return self.data.get(key)
    
    def __setitem__(self, key: str, value: Any) -> None:
        """设置条目属性"""
        self.data[key] = value
    
    def get(self, key: str, default: Any = None) -> Any:
        """获取条目属性，支持默认值"""
        return self.data.get(key, default)
    
    def fail(self, reason: str) -> None:
        """标记条目失败"""
        self.failed = True
        self.reason = reason
    
    def fail_with_prefix(self, reason: str) -> None:
        """带前缀的失败标记"""
        prefix = self.get('prefix', '')
        last_date = self.last_date()
        full_reason = f"{prefix}=> {reason}. ({last_date})" if prefix else f"{reason}. ({last_date})"
        self.fail(full_reason)
    
    def last_date(self) -> str:
        """获取上次签到日期"""
        file_name = 'cookies_backup.json'
        site_name = self.get('site_name')
        if not site_name:
            return ''

        # 从配置文件目录读取
        config_dir = self.get('config', {}).get('config_dir', '.')
        cookies_backup_file = pathlib.Path(config_dir).joinpath(file_name)
        if cookies_backup_file.is_file():
            try:
                cookies_backup_json = json.loads(cookies_backup_file.read_text(encoding='utf-8'))
                if isinstance(cookies_backup_json.get(site_name), dict):
                    return cookies_backup_json.get(site_name, {}).get('date', '')
            except (json.JSONDecodeError, FileNotFoundError):
                pass
        return ''
    
    @property
    def title(self) -> str:
        """获取标题"""
        return self.get('title', '')
    
    @property
    def url(self) -> str:
        """获取URL"""
        return self.get('url', '')
    
    def __str__(self) -> str:
        return f"SignInEntry(title='{self.title}', failed={self.failed})"
    
    def __repr__(self) -> str:
        return self.__str__()



from abc import ABC

from .private_torrent import PrivateTorrent


class Discuz(PrivateTorrent, ABC):
    @property
    def details_selector(self) -> dict:
        return {
            'user_id': r'home\.php\?mod=space&amp;uid=(\d+)',
            'detail_sources': {
                'default': {
                    'link': 'home.php?mod=space&amp;uid={}',
                    'elements': {
                        'table': '#ct > div > div.bm > div > div.bm_c.u_profile',
                        'ptconnect_menu': '#ptconnect_menu'
                    }
                }
            },
            'details': {
                'uploaded': {
                    'regex': r'上传量.*?([\d.]+ ?[ZEPTGMK]?i?B)'
                },
                'downloaded': {
                    'regex': r'下载量.*?([\d.]+ ?[ZEPTGMK]?i?B)'
                },
                'share_ratio': {
                    'regex': r'保种率.*?([\d.,]+)'
                },
                'points': {
                    'regex': r'积分([\d.,]+)金币'
                },
                'join_date': {
                    'regex': r'注册时间(\d{4}-\d{1,2}-\d{1,2})',
                },
                'seeding': {
                    'regex': r'当前做种数 : (\d+)'
                },
                'leeching': {
                    'regex': r'当前下载数 : (\d+)'
                },
                'hr': None,
            }
        }



from typing import Final

from ..core.entry import SignInEntry
# Removed reseed functionality
from ..schema.nexusphp import BakatestHR


class MainClass(BakatestHR):
    URL: Final = 'https://ptchdbits.co/'
    USER_CLASSES: Final = {
        'downloaded': [3298534883328, 4398046511104],
        'share_ratio': [8, 10],
        'points': [3500000, 5000000],
        'days': [280, 364]
    }

    def sign_in(self, entry: SignInEntry, config: dict) -> None:
        entry.fail_with_prefix("公告禁止使用脚本，请移除")
        return



from typing import Final

from ..schema.nexusphp import Attendance
from ..utils.net_utils import dict_merge


class MainClass(Attendance):
    URL: Final = 'https://azusa.wiki/'
    USER_CLASSES: Final = {
        'downloaded': [805306368000, 3298534883328],
        'share_ratio': [3.05, 4.55],
        'days': [280, 700]
    }

    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        dict_merge(selector, {
            'details': {
                'seeding': {
                    'regex': (r'[清理].*?\d+.*?(\d+)', 1)
                },
                'leeching': {
                    'regex': (r'[清理].*?\d+.*?(\d+).*?(\d+)', 2)
                },
            }
        })
        return selector


from typing import Final

from ..core.entry import SignInEntry
# Removed reseed functionality
from ..base.sign_in import check_final_state, SignState, check_sign_in_state
from ..base.work import Work
from ..schema.nexusphp import NexusPHP
from ..utils import net_utils


class MainClass(NexusPHP):
    URL: Final = 'https://pt.hdupt.com/'
    USER_CLASSES: Final = {
        'downloaded': [805306368000, 3298534883328],
        'share_ratio': [5.59, 8.85],
        'days': [280, 700]
    }
    DATA = {
        'fixed': {
            'action': (None, 'qiandao')
        }
    }

    def sign_in_build_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/',
                method=self.sign_in_by_get,
                succeed_regex=['<span id="yiqiandao">\\[已签到\\]</span>'],
                assert_state=(check_sign_in_state, SignState.NO_SIGN_IN),
                is_base_content=True
            ),
            Work(
                url='/added.php',
                method=self.sign_in_by_post,
                data=self.DATA,
                succeed_regex=['\\d+'],
                assert_state=(check_final_state, SignState.SUCCEED),
            )
        ]

    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        net_utils.dict_merge(selector, {
            'details': {
                'hr': None
            }
        })
        return selector



from typing import Final

from ..core.entry import SignInEntry
# Removed reseed functionality
from ..base.sign_in import check_sign_in_state, SignState, check_final_state
from ..base.work import Work
from ..schema.nexusphp import NexusPHP
from ..utils import net_utils


class MainClass(NexusPHP):
    URL: Final = 'https://hdarea.club/'
    USER_CLASSES: Final = {
        'downloaded': [1099511627776, 10995116277760],
        'share_ratio': [4.5, 6],
        'days': [140, 280]
    }

    DATA = {
        'fixed': {
            'signed_timestamp': '(?<=signed_timestamp: ")\\d{10}',
            'signed_token': '(?<=signed_token: ").*(?=")'
        }
    }

    def sign_in_build_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/',
                method=self.sign_in_by_get,
                succeed_regex=[
                    '<span id="sign_in_done"><font color="green">\\[已签到\\]</font></></font>&nbsp;\\(\\d+\\)'],
                assert_state=(check_sign_in_state, SignState.NO_SIGN_IN),
                is_base_content=True
            ),
            Work(
                url='/sign_in.php?action=sign_in',
                method=self.sign_in_by_post,
                data=self.DATA,
                succeed_regex=['已连续签到.*天，此次签到您获得了.*魔力值奖励!|请不要重复签到哦！'],
                assert_state=(check_final_state, SignState.SUCCEED)
            )
        ]

    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        net_utils.dict_merge(selector, {
            'details': {
                'hr': None
            }
        })
        return selector



from __future__ import annotations

import re
from typing import Final

from requests import Response

from ..core.entry import SignInEntry
from ..base.request import check_network_state, NetworkState
from ..base.sign_in import check_final_state, SignState, Work
from ..schema.private_torrent import PrivateTorrent
from ..utils.net_utils import get_module_name
from ..utils.value_handler import handle_join_date, handle_infinite


class MainClass(PrivateTorrent):
    URL: Final = 'https://www.myanonamouse.net/'
    USER_CLASSES: Final = {
        'uploaded': [26843545600],
        'share_ratio': [2.0],
        'days': [28]
    }

    @classmethod
    def sign_in_build_schema(cls) -> dict:
        return {
            get_module_name(cls): {
                'type': 'object',
                'properties': {
                    'login': {
                        'type': 'object',
                        'properties': {
                            'username': {'type': 'string'},
                            'password': {'type': 'string'}
                        },
                        'additionalProperties': False
                    }
                },
                'additionalProperties': False
            }
        }

    def sign_in_build_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/login.php',
                method=self.sign_in_by_get,
                assert_state=(check_network_state, NetworkState.SUCCEED),
            ),
            Work(
                url='/takelogin.php',
                method=self.sign_in_by_login,
                succeed_regex=['Log Out'],
                response_urls=['/u/'],
                assert_state=(check_final_state, SignState.SUCCEED),
                is_base_content=True,
                t_regex='<input type="hidden" name="t" value="([^"]+)"',
                a_regex='<input type="hidden" name="a" value="([^"]+)"',
            )
        ]

    def sign_in_by_login(self, entry: SignInEntry, config: dict, work: Work, last_content: str) -> Response | None:
        if not (login := entry['site_config'].get('login')):
            entry.fail_with_prefix('Login data not found!')
            return None
        print(last_content)
        t = re.search(work.t_regex, last_content).group(1)
        j = len(t)
        a = re.search(work.a_regex, last_content).group(1)
        data = {
            't': (None, t),
            'j': (None, j),
            'a': (None, a),
            'email': (None, login['username']),
            'password': (None, login['password']),
            'rememberMe': (None, 'yes')
        }
        response = self.request(entry, 'post', work.url, data=data)
        return response

    @property
    def details_selector(self) -> dict:
        return {
            'user_id': '/u/(\\d+)',
            'detail_sources': {
                'default': {
                    'link': '/u/{}',
                    'elements': {
                        'bar': '.mmUserStats ul',
                        'table': 'table.coltable'
                    }
                }
            },
            'details': {
                'uploaded': {
                    'regex': r'Uploaded\s+?([\d.]+ [ZEPTGMK]i?B)'
                },
                'downloaded': {
                    'regex': r'Downloaded\s+?([\d.]+ [ZEPTGMK]i?B)'
                },
                'share_ratio': {
                    'regex': r'Share Ratio.*?(∞|[\d,.]+)',
                    'handle': handle_infinite
                },
                'points': {
                    'regex': r'Bonus:\s+([\d,.]+)'
                },
                'join_date': {
                    'regex': r'Join date\s*?(\d{4}-\d{2}-\d{2})',
                    'handle': handle_join_date
                },
                'seeding': None,
                'leeching': None,
                'hr': None
            }
        }



import re
from datetime import datetime
from typing import Final

from dateutil.relativedelta import relativedelta

from ..core.entry import SignInEntry
from ..base.request import check_network_state, NetworkState
from ..base.sign_in import SignState, check_final_state
from ..base.work import Work
from ..schema.private_torrent import PrivateTorrent
from ..utils.net_utils import get_module_name


class MainClass(PrivateTorrent):
    URL: Final = 'https://abn.lol/'
    USER_CLASSES: Final = {
        'uploaded': [5368709120000],
        'share_ratio': [3.05]
    }

    @classmethod
    def sign_in_build_schema(cls) -> dict:
        return {
            get_module_name(cls): {
                'type': 'object',
                'properties': {
                    'login': {
                        'type': 'object',
                        'properties': {
                            'username': {'type': 'string'},
                            'password': {'type': 'string'}
                        },
                        'additionalProperties': False
                    }
                },
                'additionalProperties': False
            }
        }

    def sign_in_build_login_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/Home/Login?ReturnUrl=%2F',
                method=self.sign_in_by_get,
                assert_state=(check_network_state, NetworkState.SUCCEED),
            ),
            Work(
                url='/Home/Login',
                method=self.sign_in_by_login,
                succeed_regex=[r'Déconnexion'],
                assert_state=(check_final_state, SignState.SUCCEED),
                is_base_content=True,
                response_urls=['/'],
            )
        ]

    def sign_in_build_login_data(self, login: dict, last_content: str) -> dict:
        return {
            'Username': login['username'],
            'Password': login['password'],
            'RememberMe': ['true', 'false'],
            '__RequestVerificationToken': re.search(
                r'(?<=name="__RequestVerificationToken" type="hidden" value=").*?(?=")', last_content).group(),
        }

    @property
    def details_selector(self) -> dict:
        return {
            'detail_sources': {
                'default': {
                    'link': '/User',
                    'elements': {
                        'points': 'div.navbar-collapse.collapse.d-sm-inline-flex > ul:nth-child(6) > li:nth-child(3)',
                        'stats': 'div.row.row-padding > div.col-lg-3 > div:nth-child(2) > div.box-body',
                    }
                }
            },
            'details': {
                'uploaded': {
                    'regex': r'''(?x)Upload\ :\ 
                                    ([\d,.] + \ [ZEPTGMK] ? o)''',
                    'handle': self.handle_amount_of_data
                },
                'downloaded': {
                    'regex': r'''(?x)Download\ :\ 
                                    ([\d,.] + \ [ZEPTGMK] ? o)''',
                    'handle': self.handle_amount_of_data
                },
                'share_ratio': {
                    'regex': r'''(?x)Ratio\ :\ 
                                    (∞ | [\d,.] +)''',
                    'handle': self.handle_share_ratio
                },
                'points': {
                    'regex': r'''(?x)Choco's\ :\ 
                                    ([\d,.] +)''',
                    'handle': self.handle_points
                },
                'join_date': {
                    'regex': r'''(?mx)Inscrit\ :\ 
                                    (. +?)
                                    $''',
                    'handle': self.handle_join_date
                },
                'seeding': None,
                'leeching': None,
                'hr': None
            }
        }

    def handle_amount_of_data(self, value: str) -> str:
        return value.replace('o', 'B').replace(',', '.')

    def handle_share_ratio(self, value: str) -> str:
        return '0' if value == '∞' else value.replace(',', '.')

    def handle_points(self, value: str) -> str:
        return value.replace(',', '.')

    def handle_join_date(self, value: str) -> datetime:
        value_split = value.removeprefix('Il y a ').replace('et', '').replace('seconde', 'second') \
            .replace('heure', 'hour').replace('jour', 'day').replace('semaine', 'week') \
            .replace('mois', 'months').replace('an', 'year').replace('années', 'years').split()
        return datetime.now() - relativedelta(**dict(
            (unit if unit.endswith('s') else f'{unit}s', int(amount)) for amount, unit in
            [value_split[i:i + 2] for i in range(0, len(value_split), 2)]))



import re
from typing import Final

from requests import Response

from ..core.entry import SignInEntry
# Removed reseed functionality
from ..base.sign_in import check_final_state, SignState, Work, check_sign_in_state
from ..schema.nexusphp import Attendance
from ..utils import net_utils


class MainClass(Attendance):
    URL: Final = 'https://www.pttime.org/'
    USER_CLASSES: Final = {
        'downloaded': [3221225472000, 16106127360000],
        'share_ratio': [3.05, 4.55],
        'days': [112, 364]
    }

    def sign_in_build_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/',
                method=self.sign_in_by_get,
                succeed_regex=['签到详情'],
                assert_state=(check_sign_in_state, SignState.NO_SIGN_IN),
                is_base_content=True
            ),
            Work(
                url='/attendance.php?type=sign',
                method=self.sign_in_by_userid,
                succeed_regex=[
                    '签到成功',
                    '今天已签到，请勿重复刷新'],
                assert_state=(check_final_state, SignState.SUCCEED),
            )
        ]

    def sign_in_by_userid(self,
                          entry: SignInEntry,
                          config: dict,
                          work: Work,
                          last_content: str = None,
                          ) -> Response | None:
        if useridMatch := re.search(r'userdetails\.php\?id=(\d+)', last_content):
            userid = useridMatch.group(1)
            work.url = work.url + f'&uid={userid}'
            work.response_urls = [work.url]
            return super().sign_in_by_get(entry, config, work, last_content)

    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        net_utils.dict_merge(selector, {
            'detail_sources': {
                'default': {
                    'elements': {
                        'bar': '#info_block',
                    }
                },
            },
            'details': {
                'seeding': {
                    'regex': r'活动:.*?(\d+)'
                },
                'leeching': {
                    'regex': (r'活动:.*?(\d+).*?(\d+)', 2)
                },
            }
        })
        return selector

    def get_nexusphp_messages(self, entry: SignInEntry, config: dict, **kwargs) -> None:
        super().get_nexusphp_messages(entry, config, unread_elements_selector='td > i[alt*="Unread"]')



from __future__ import annotations

from collections.abc import Callable


class Work:
    def __init__(self,
                 url: str,
                 method: Callable,
                 data: dict | None = None,
                 succeed_regex: list[str | tuple] | None = None,
                 fail_regex: str | None = None,
                 assert_state: tuple | None = None,
                 response_urls: list[str] | None = None,
                 use_last_content=False,
                 is_base_content=False,
                 **kwargs,
                 ) -> None:
        self.url = url
        self.method = method
        self.data = data
        self.succeed_regex = succeed_regex
        self.fail_regex = fail_regex
        self.assert_state = assert_state
        self.use_last_content = use_last_content
        self.is_base_content = is_base_content
        self.response_urls = response_urls if response_urls else [url]
        for key, value in kwargs.items():
            self.__setattr__(key, value)



from typing import Final

from ..schema.nexusphp import Attendance
from ..utils.value_handler import size


class MainClass(Attendance):
    URL: Final = 'https://ihdbits.me/'
    USER_CLASSES: Final = {
        'downloaded': [size(2048, 'GiB'), size(16384, 'GiB')],
        'share_ratio': [6, 10],
        'days': [280, 700]
    }



from typing import Final

# Removed reseed functionality
from ..schema.nexusphp import BakatestHR


class MainClass(BakatestHR):
    URL: Final = 'https://52pt.site/'
    USER_CLASSES: Final = {
        'downloaded': [2748779069440, 6047313952768],
        'share_ratio': [3.05, 4.55],
        'days': [280, 700]
    }



import re
from typing import Final

from ..schema.luminance import Luminance


class MainClass(Luminance):
    URL: Final = 'https://www.happyfappy.org/'
    USER_CLASSES: Final = {
        'uploaded': [54975581388800],
        'share_ratio': [7],
        'days': [196]
    }

    def sign_in_build_login_data(self, login: dict, last_content: str) -> dict:
        return {
            'token': re.search(r'(?<=name="token" value=").*?(?=")', last_content).group(),
            'username': login['username'],
            'password': login['password'],
            'cinfo': '1920|1080|24|-480',
            'iplocked': 0,
            'keeploggedin': [0, 1],
            'submit': 'Login',
        }



from __future__ import annotations

from typing import Final

# Removed reseed functionalityCookie
from ..schema.nexusphp import AttendanceHR
from ..utils import net_utils


class MainClass(AttendanceHR):
    URL: Final = 'https://audiences.me/'
    USER_CLASSES: Final = {
        'downloaded': [2199023255552, 8796093022208],
        'share_ratio': [4.5, 5],
        'points': [1200000, 1800000],
        'days': [560, 784]
    }

    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        net_utils.dict_merge(selector, {
            'detail_sources': {
                'default': {
                    'elements': {
                        'bar': '#info_block > tbody > tr > td > table > tbody > tr > td:nth-child(1)',
                    }
                }
            },
            'details': {
                'points': {
                    'regex': '做种积分([\\d.,]+)',
                }
            }
        })
        return selector



from __future__ import annotations

import ast
from typing import Final
from urllib.parse import urljoin

from requests import Response

from ..core.entry import SignInEntry
from ..base.request import check_network_state, NetworkState
from ..base.sign_in import check_final_state, SignState, Work
from ..schema.xbt import XBT


class MainClass(XBT):
    URL: Final = 'https://abtorrents.me/'
    USER_CLASSES: Final = {
        'uploaded': [536870912000],
        'share_ratio': [1.5],
        'days': [90],
    }

    def sign_in_build_login_workflow(self, entry, config: dict) -> list[Work]:
        return [
            Work(
                url='/login.php?returnto=%2F',
                method=self.sign_in_by_get,
                assert_state=(check_network_state, NetworkState.SUCCEED),
            ),
            Work(
                url='/simpleCaptcha.php',
                method=self.sign_in_by_get,
                assert_state=(check_network_state, NetworkState.SUCCEED),
            ),
            Work(
                url='/takelogin.php',
                method=self.sign_in_by_login,
                succeed_regex=['Logout'],
                assert_state=(check_final_state, SignState.SUCCEED),
                is_base_content=True,
                response_urls=['/']
            )
        ]

    def sign_in_by_login(self, entry: SignInEntry, config: dict, work: Work, last_content: str) -> Response | None:
        if not (login := entry['site_config'].get('login')):
            entry.fail_with_prefix('Login data not found!')
            return None
        last_content_json = ast.literal_eval(last_content)
        target = {
            'light bulb': b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\x00\x000\x08\x03\x00\x00\x00`\xdc\t\xb5\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\xc9e<\x00\x00\x00\x9cPLTEGpL\xd0z\x00\xd0z\x00\x99\x99\x99\xd1{\x00\xd0z\x00\xd0z\x00\x99\x99\x99\xd0z\x00\xd0z\x00\xd0z\x00\xf7\xa9%\xf8\xad*\x99\x99\x99\xcc\xcc\xcc\xf7\xa6"\xf6\x9c\x17\xfd\xd6]\xf7\xb2,\xf8\xb72\xf7\xa3\x1e\xfa\xc6D\xf7\xa0\x1d\xfe\xdbd\xfa\xbc7\xfb\xcdP\xf5\x97\x12\xfc\xd0W\xfc\xc4K\xfe\xdfl\xc2\xc2\xc2\xf8\xbf<\xf9\xb13\xfb\xb9?\xfb\xc4<\xec\xec\xec\xba\xba\xba\xe1\xe1\xe1\xd7\xd7\xd7\xae\xae\xae\xff\xff\xff\xff\xe5v\xdb\x83\x05\xfd\xebV\xff\xd5E\xdf\x9c\x18\xfb\xe2L\xf5\x8e\t\xdb\x8b\x0c\xea\x8e\x0c\xeb\x9d\x1c\xff\xfa]\x9d^\x95\xf1\x00\x00\x00\x0btRNS\x00?\x92@\xfef\xe4\x94\x83\xc9\x9c\xc0v{\x81\x00\x00\x02\x18IDATH\xc7\xcd\x96\xdb\x9a\x9a0\x14F\xd5A M\x90\xf3I\x98\t2mi9\xa3\xef\xffn\xdd;8\x0e\xfa\x05a\xae\xa6\xeb\xc3\x0b\xe0_\xec\x1db\xa2\x9b\xcdw\xb0\xd5\x89\xaa(*\xd1\xb7\xab\xe2\xba\xda\xf0\xb6\xba\\\xaa\xd6mT}1\xbe\'Nu\xa9B;\x89k\xb0\xaa\x86\xec\x17\x1e\xdf\xb7\x90\x06\x928\x8e}\xbf\xae\xda\xfei\x91]S\x85\x02a\xf8`\xd4m\xb3{\xf2|\xc8\xdb\xe1+\x00\x86\x10r\x1f\x8c\xd9\x1a\xfb\xbe\xb5\xc7<\x1a\t\x089P\xd7\xfd\xdc8Hn\' \xfc\x05>\x04\xcey^s2S\xa0\xa9\xe3{\x01\xf3h4\xf2\x12Jt\'\xc0\x188\x8f\x90\xdcU\xa4\xf3\xdb\xe7\xbe/\x8c\xd7[\x01\x8c\xbb`\xf4\xb29\xd7\xcf9\xf7\xd3D\x0c\x1b\xf3\xa9\xcf#w$:\xcb^\x14\xa1Q\x04\x06\xd4\x10\xf36\xc9\xbb\x11\x95\r[ep\x07\x8d8\x81I\x13y\xe7\x8a\xcbT\xd9\x98\xf1\x8e\xcb\xb9/\xc0\xc7;\x9f\xc8F\xad0\xc0\xc1*\'~\xc28\x9b \x13T\x93R\n\x8a\x93\xb9n\x86i\xca\xe8\xf5\xa0\xa6\xac%r\xa6#\xf8Dz\xcfY6\xe8\xdd`\xde\xc0\x909a\x90\xbd\xd6m\xe9}0\x1a\xf4v\xee\x95\xd2\xc5\xaaX\xc1\x88gR\xd1\x95\xe9]\xcf\xcfdf\xb5Y\x96\x15\xc0\xe1A>\xcb\x18\x03A\\\xb0\xca\x99\xef\xb7r\xb4\x10\x102\x84Q\x14\x80\x81\xcc-\xa0\xf2\x08X\x81\xc9\xb2\x13\x9013\xb0\xf0\x8a2\xbb\x11\xe8\xa5\x10(\xe4S4h\x80\xf9\xf2\xc96\xb0+Q\x80\x02)p\x15\xca\xdd\xb3m\x83\x0cG\xcbc\x90\x8fQ` \x0c\xca\xf3]R\xe9,\x0f\n$v\x92\xa4\'\xe6\x1d\xbbra\'\xfb1t\x01\n\xb0\x84@\x08\xba\xd974)\xd1\xd1Sj\x87!\x08A\xb7X`\xa3\x19\x0fh\x0b\x82\xf1\xfe\xe7\x8ewc\xb1B\xf16\xa1X\xac\x00\xc2aB\xb1\xa2\xa5\x07\xfe\x83\x96~=\xb0\xdc\x92Q\xfc\xbcQ,\xcf\x03(\xd0\xd3\xdba\xfc\x14\xda\x8a\x9f]\xe3\xf7\x04c\x85\xf0\xd9\xd4\xaa\x86\x04/\x1a\x941\xb4\x97/\xfc{0\x0e\x07c\xf3\x15\xb4\xd5\xdd,\xf2\x0f\xa8`W(\x90\xd4\rZ\x00\x00\x00\x00IEND\xaeB`\x82',
            'house': b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\x00\x000\x08\x03\x00\x00\x00`\xdc\t\xb5\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\xc9e<\x00\x00\x00\xc3PLTEGpL\n[u\x99\x99\x99\x89\x9d\xa4\n[u\n[u\x99\x99\x99\n[u\x1dbyOw\x85\n[u\n[u*i}5n\x805m\x80\n[u\xe5\xe5\xe5\xea\xea\xea\xe1\xe1\xe1\xde\xde\xde\x99\x99\x99\xdc\xdc\xdc\xe7\xe7\xe7\xd9\xda\xda\xed\xed\xed\x15v\x96\x1c\x8c\xaf\x0fe\x81\x13n\x8b\x0b^x\xb2o4\x9e\x87z&\xaf\xd8\x1d\x93\xb8\x1f\x98\xbf\x17~\x9f\x1a\x84\xa6!\x9e\xc6\xbf\x80?\xd0\x93K\xa5`*\xd9\x9eR\x9dW#"\xa3\xcc$\xa7\xd1\x98\x82u(\xb8\xe5/\xcf\xfc,\xc5\xee\xc8\x8aEzcV\xde\xa4W\xff\xd2p\x83\xa9\xb5a\x92\xa2\xbc\xb7\xb5o\x9c\xaa\xff\xff\xff\xce\xd3\xd4M~\x8d\x98\xb5\xbe\xb7\xca\xd0\x9a\x9a\x9a\xff\xc0f2m\x7f9\xaf5\xfb\x00\x00\x00\x10tRNS\x00t\xe9\xf3\xb0\xe9\x8f\x8bF\x1fc\x9c\xaa\xd7\xd6\xd2\xbe`\xb9\x07\x00\x00\x02+IDATH\xc7\xc5\x96\x8b\x92\x9a0\x14@\xd5Q\x81\xb5\x0f@\x16MB\x1a\x82\xd8\xda\x15\x81>\x04\xeacw\xff\xff\xabJ\x08$\xc8\xcb\x9di\xa7=\x81\x19r\xef=I`\xe2\xc4\xd1\xe8\xbf3\xb7\x18\xf3{e\xeab\xa1\xf2\'\xeb\x17\xc3\xbaS?\xc6\xae\x8b\xc7\\X3\xee\x08\x8a\x13GQ\xec(o\x14\xd4)\x8c\xa20\x8c"8\xcd\x97e\x19\x8c!a\x8c\xdc(\x0es\xe2\xc8E\xe3\x91e3\xfa\x05M\x01q\x1c\xba\x05a\x1c\x03\xc5\xd2\x19V\xffrhT\x96\x17JD_/f\x8e\xd5\xbf\x9c\xd8\rj\xe4]\x94-\x97\xcbnA[\x800\x0c\xf67\x04a\x08\x92\xd3c\xa7\xf0\x80i\xe8n[\xb8!\xc5\x97.\xe1\x1d\xda\xbb[\xaf\x84\x02\x87V\xcf[w\x8f\xce\xed\xb7}\x0f\xdc\xbdGK|\x94\x1d\xf1\xa6\xeay\xfb\x00|P\x9b\xcb\x81\x81\x07!\xa4\x90\x01\xf0e\xbd\xbe&N\xd5\xa7^\x00\xf1\xc3\xcd^@\xde\xb6H\xf9\xecF\x99Y\xec\x87\x0co`\x15\xddzH\xa9}|\xe0Q\xbf\xc2a\xc3s\xaegG\x84\xa9\x07\xa6j5<\xa4\xfe\xa6\x04\xa0l\xb56D\xcb0\xa82>\x85|\x921\x82\xfe\x06\x00\xc0n\xe0\xe0\xa3Qg}9#\xc0\x93\xb9\x02\x11{\x91\x19/\xe5\xe5\xc9\xc9h\xb0\xcc\xb0S\xe57\xe0c.`\xa7\x025\x86/9b$Jfu\x01\'W\xc3\xeeh\xc6*\xc1ua\x86\n0>\xe6\xd9\x0eX0\x9f\x84\xc3\x04\xa5\xe8\xe4\xc3\xdb\x03\\\x13^\xc5>\x93\x86\x19g\xbd\x1f[\xb7m\xfd\\\x94i\xfcG6\x9b\xaa\x96~\x07K\x9d\xce\x14Mn\x8e\xfbBc\xb7\xe6\x82Y^)\x11\xa42\xda\x12LS/.\xd3$/?K^H\x15\xd5\xcd\xb6PeL\xf2C@d\xb4c\x86\n\xf2U@d\xf4\xcf\x85\xa5\x80|\x11\x10\x19m\x0bf\xd9n\x05\x11\x1d\x9a\xe1\x9b`h\x86G\x01\xf9, 2\xfaW\x85O\x82\xb7\t\x07)\x1c\x06\x84\x95@\n;"\xa3C\xc2Np\xe8\x17&\xa7\xba\xf0\xb4\xe3\xb7\x14N\x93\xe6\xf9\x9dJ\xe1I \x85\xb4y\xb4k\xcf\xe9\xa9_8\xa5\xcfZ\xeb\xf8\x99O,\xce\xe1\xbb\xe0P\x86&s\xed\xdf\xfdY\xf9\r\xe0m\x99\xfb\xc4aP\x89\x00\x00\x00\x00IEND\xaeB`\x82',
            'musical note': b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\x00\x000\x08\x03\x00\x00\x00`\xdc\t\xb5\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\xc9e<\x00\x00\x00oPLTEGpL\n[u\n[u\n[u\n[u\n[u\n[u\n[u\n[u\n[u\n[u\n[u\x13n\x8c\x14r\x91\x10e\x80\x12j\x86\x16w\x97\x17}\x9d(\xb2\xde\x1c\x8c\xb1\x0ea{#\xa3\xcc%\xaa\xd3\x19\x86\xa8)\xb6\xe3\x1d\x93\xb9\x18\x81\xa2\'\xaf\xda!\x9c\xc4&\xad\xd7*\xbb\xe9\x1f\x98\xbf-\xc9\xf95\xea\xff\x1e\xa1\xb51\xdb\xfc,\xce\xe4)\xcb7\xf0\x00\x00\x00\x0btRNS\x00\xcc"Y\x0f\xb4:\xddy\x97\xee\x7f\xdbj\x8c\x00\x00\x01\x95IDATH\xc7\xd5\x95\x81N\x830\x10\x86\xc7V\xb8\xd6\x83\xd2JY\xd7\x8a"\xd3\xf7\x7fF\x8fM\x94\x96\xd9\x9ahb\xfc\xc2\xb2\xf5\xbf\xfb\x80[\x13\xd8\xed\xfe#{^ \xf0\xefvW\x1c\xda\xf3\xeb\xf4\n\xdf\xea>\x08T\xe7\x97\xe9\xe5\xf9\xe9!/0.\xd0\x9e\xa7\xb9\x9bx\x84\\w\x89\xe7\xe34=S\xf7i>\x92\xc2<$\xdd6\x9d\xfa\xf4\xc11!\x886\xee\xce\x08H\xf7q\xba\x8fH\n\xf77\xe8S\xc2C\x84\xa7ORx\\\xd1\xfb\x16\xe7 )\x1c\x17\x9c7\xc0\xabK0\xe4\x85\xcec\xc9\xd9\x12$\x85\x9ehP\\\xbb\xdf\x83\x9c0B*\xd8\x08C,\x0cia\x18\x06\x07\xa9\xe0\xc7\xc28\x8e\x1d\xa4\x82Xp\xce\x85B\x1c\xfcX\xe8\xba\xceB*\xf8M\xe1\xc09?d\x05k\xad\x9f\xebU\x89\x8a~kt\xefAB\xd0T\xe7\xd2\x1d{\xda\x82~t\xd7\xe0K\xc1{Ou.\xa9\xd1/$\x05\xad\xb5\x02fl\xe7\xf5\x07\n\xbex.r\xbe\xbf\n\xbc\xb6Z\xa7\x05\x9a\xb1\xa6\x92D\xaf\x94\x82\xa2\xd1j\xcdV\xe0\xc6\x8e\x8e\xfe@\xd7\x91\xd0\x004A\x7f]n\xfa\xa5\xf5\xaa\xb90\x7f\x91\x10\xd0\xc6\x02C\xa5\x97bM\x07\x14u H\xbe\xb9\x80\xaa\xd7\x80\x90\xc1\x1a\xf7\x91P\xb4\xcd\xba\xde\x16\x15\xae\xd7R\xc4#@\x1b \xcb\x9d0\x9fK#\xd8F\x90\xa1@g\x14x\xcd\xa4A\xb1\xdd\x04\x90\x01f\x9e\xb1\x128\x03\x9c\xdd\xd8\xe3\xd2\x04\x02\xb2\xec\xcb\x127\x17\xc8 \xcc\'(X^`\x02\x97\xf6[3\xde|)\x97\x97\x19\xef8\xdb\xfd-o\xc4\xdb8 \xfcR[\xf5\x00\x00\x00\x00IEND\xaeB`\x82',
            'key': b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\x00\x000\x08\x03\x00\x00\x00`\xdc\t\xb5\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\xc9e<\x00\x00\x00cPLTEGpLEi\x05Ei\x05k\x92.Ei\x05Ei\x05Ei\x05\x99\x99\x99Ei\x05Ei\x05Sy\x13b\x8a$Mr\x0c\x97\xc2`t\x9c9\x99\x99\x99\xdd\xdd\xdd\x86\xafL}\xa6C\xe6\xe6\xe6\\\x83\x1eX~\x19\x8d\xb9P\xed\xed\xed\x93\xbd[\xb9\xedx\x8f\xb9X\xf0\xf0\xf0\xfe\xfe\xfe\xa8\xd8j\xbb\xbb\xbb\xc0\xc0\xc0\xc3\xc3\xc3\xe9\xea\xbc\x88\x00\x00\x00\ntRNS\x00\xae\xff\xff\xaa\x17\x84\x96\xecBp@\r\xa8\x00\x00\x01(IDATH\xc7\xbd\x94\xd1r\x83 \x10E\x134F\xad\xc8\n-\xa6X\xd2\xfc\xffW\x16\xac\xc5\xc0\x84\xecZ\xa7=\xbe\xed\xdc#\x17F9\x1c\xfe\x8d\xa6\xacY\x96\xbal\xd2|\xd5i\xfb\x9e\xc5\xea\xb6J\xde\xdfZ\xcb\xf3Xk\xdbx\x8dR\xf2g\\8\x97\xc7H\xa8\r\xbf<\x85\x9b:\x12\x98\t\x14w\x9b-\xd6\xb1a\xb1\xa0\xcd\xf2hv\n\xd3\xd3:6:\x11\x86\x00{<\x1e\xf6\n2\x10U\x92w\xf3\x8c0D\x9b\x1e\xb2B\xff\x83\x1c\xf4\x8a\x94a\xde\xe7\x84\xbe\xe8\x1f\x93\x08\x05\xca^\xe1\x05e\xaf\xf0\x8a\x92\x08o(\xb1P\xb7(\xf1\xe7}\xec\xb0|\x17\xff@\r\xeb\x10Xr\rT\x88\xc1\xaa\xbd\xd7\xcc\x8a\x98<\xb7iA\xa07\x9a\x18=\xb7\xf1\x1bqF\x85\xb3\x10"\x08\x84\xfc\xac|,\x029\xbf\x08\xf4\xbcR\x9fJ)Z\xde\x9d\x92\xcb\x8fN\x18\x05\xed\xde\x17\xca3\xaf@\x13\xdc)m\x13\xdc\x16\xa6m\x82o\x04N\x00z%\x00u\x05\x80\r\x95\x00\xae@^\xc1\xbd\x1f\xbc\x00\x9b*\xc1/*\xc1\xdfW"~J\xbe\xd2\xe8\x8f\x95\x9a_*\xd1\xf3\xf3\x1f\xe7 \xe71\xbe\x00\xaaf:y~\xf1\xbf@\x00\x00\x00\x00IEND\xaeB`\x82',
            'bug': b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\x00\x000\x08\x03\x00\x00\x00`\xdc\t\xb5\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\xc9e<\x00\x00\x00\xb4PLTEGpL\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\xbe>\x1a\x14\x14\x14+\x19\x14\x14\x14\x14\x14\x14\x14\xbe>\x1a\xbe>\x1a\xbd=\x1a\xbe>\x1a\xbe>\x1a\xbe>\x1a\xbe>\x1a\x14\x14\x14\x14\x14\x14s+\x17\x8b1\x18\x14\x14\x14z-\x18\xe7x\'\xdb_\x1c\xd7Y\x1a\xc0,\x06\xddd\x1e\xca@\x0e\xe0j \xc54\t\xe3r$\x17\x17\x17\xd3S\x18###\xd2O\x15\xbe=\x18\xd0J\x13\xea~)777\xe3m"\xceF\x11\xc7:\x0b\x1e\x1e\x1e,,,DDD\xf9\x86,\xe9q$\xc8I\x1b\xeb\x81+\xfd\x910\xed\x84+WWW\xee\x982\xff\xa9:\x997\x1c\xf2x\'c2$\xdaG\x0c\xac:\x1a:\xff\xca.\x00\x00\x00\x17tRNS\x00\xb8\x85>u\x89I\x15"_u6\xe2\xad\xc5Y\xcf\x08\xab\xc8\xb9\xe5\xd7\x83I\x8cy\x00\x00\x02\xaaIDATH\xc7\xddUks\xaa0\x10E\x04\r\x16\xb4\xb5\x0f@k\t1\x1aZ\x02\x89<D\xeb\xff\xff_w\xb1U\x032\xb5\xdf:s\x0f3&k\xf6\x10\x92=\xbb\xabi\xff\'\x86#\xe7\x9e\xd2{g4\xfc\x95\xfb\x9d)\x83\xb2\xdcn\xcb2\x90\xe6\xddm\xff\x11u\xb7\xdb,K\xd3,\xdbn]:\xba\xe9/\xc19\xcf7\xf0\xe49\x90\xe4\r\xc6D\xa6\xd9f}\xc6&K\xe5\xe4G\xc2X\xa4n\x03\xa9\x18\xff\xb8A\xb8\x13A\x03b\x17vm1\xe8\xe9\xa8\x1e\x1dO,Z\x10\x9eS\xaf \xbd7P\x08\xbd$\x89\r\x18mo1oa\xe1\xd9\xb0`\xc4I\xd2S\x08\x06g\x05\xeek\x1a\xf5;@5\xad\x8f\x0b\xc6\r\x85\x80b\xce\x12\xd2\xd7\xec0\\\xfa\xf5{=@=\xfa\xcb0\xb4\xb5>I\x18\x8f\x91z\x08\x84\t|\x15r\xa4\x0c\\\x11\xc1\xa7\xcf\x03\xf8\x89\x84\x1bI\xe9 \xf8\x1e\x82Q\xf3\xd8\x08\xb3\x84\x1b\x8e\xcc\xbf\xaf5\xd8|_k.\x1d\x83\'\xac\xed\xaf\rk\xc2K\x98e\xf9\xe6\x08\xb7\xfc\x1a7Y\x16\xbe\xd4\x84\xe15\x81\xede\x9a\x9eb,\xca\xd3,M\xe5\x9e]\x134\x9d\xb0j\x97\xaeO\x11\x8e\xca\xd3l\x9d\xee*F\xf4\xeb$\xc0\xfb\xf0\xe2\xef\xce\xcf\x04w\x97\x86{\xdc\x91\x1a\xd6A\xec.\x92\xf0\xca\xcb|\'\x0eVW\xe2H!\xa23\xfc\xf22\x17Bv%\x92\x19\xaa:\xf2KUO\xa1\xa98\xf6\xa7\xb8g!\xa4W~\xa4H(,\x15#\xf2+\x1d!\xab\x87\xa7 \x1fm\xca\x8a\x82\x10\xc2\xa97W\x9ee\xde0)\x07\x97\xa2`\xd3z\x07\x0c\xb2(\x8a\x82\xfa\x9e\xe7\x9f\x9f\xd5Z1<\x9f\x82\x03\xc8\xa3\x16(\\(\x08\x893\xd6T\xea\xbb\xdbT,c\x1c\xe4t\xba\xdc\xa1\x1es~\x08U\xbc\x06\xaa\xb5<p\x1e\xebJ,\x86\xc63\xaeVK\x05\xaf\x91j\xad*\xfcl\xb4cg\xca\x95\x82\x8f\x85jI\xb3+p\xf4]\xc1\xc7\\\xb5hg\x05\xb4_\x15\xbcy\xaaew\xf9\xa3G\xaa\xb8\xcc|\xc5\xa0\x8f\xa8\xa3dcV}\\0\xfbT\x8c\xaa#\x1d\x86\x10\xbd=};c\xf6y\x99\xd3=\xc4\xac\xcd\x18\x10(\x1bO\xb4\x8b@\x9f\xa0h\x90A;\x1b\x08c\xc40\xe9\xec\x84\xcf\xd3\x84\x9aF\xbd\xd6\xce\x08\xf8\x93\xc7\x96va\xbc}\x0f\xd4\xd4,\xa8Z\xc4h\x13b\xd0\nHk2\xa6*\x81\x8e\'\xb5<\t\x8f\xdb\x04P\x13\xc6\x0f\xc7\x96b\x9fw\xa1\xf6\xb1\x9d<`\x0cJj\x1d!\x8e\xe3/\xffc\x97\x1b\xd7Mq|\xeep\x0f\x18\x96\x1b\x87\x18\xe0\xd6\x1fW\x15\x02\xde\xd7(\xf7\x04[?\xf72\x0b\x93^\xa3\xa1\x0cnu\xcb_\xb8\xfc\x15\xfe\x01\xf2*\x8e\xfd\xc7WX\x18\x00\x00\x00\x00IEND\xaeB`\x82',
            'heart': b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\x00\x000\x08\x03\x00\x00\x00`\xdc\t\xb5\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\xc9e<\x00\x00\x00{PLTEGpL\xbe>\x1a\xbe>\x1a\xbe>\x1a\xbe>\x1a\xbe>\x1a\xbe>\x1a\xbe>\x1a\xbe>\x1a\xbe>\x1a\xbe>\x1a\xbe>\x1a\xdef\x1f\xe3p$\xd5T\x17\xccB\x0f\xeb\x7f*\xd9]\x1b\xdba\x1d\xe0l"\xe9|)\xd7Z\x1a\xbf>\x18\xe8y(\xd2O\x15\xe5v&\xee\x82,\xc66\n\xd0K\x13\xceH\x12\xc21\t\xfb\x8c/\xc9>\r\xc8:\x0c\xee\x88.\xfd\x994\xc5E\x1a\xc0+\x04\xff\xad;\xccR\x1e\xe2z,%\xf8v\x07\x00\x00\x00\x0ctRNS\x005\xd2P\x8df\x0b\x9b}!\xb8\xe96C\xc4\x16\x00\x00\x01\x96IDATH\xc7\xed\x95\xcdv\x83 \x10\x85\xa3\xa2\xa81\xa9Q3F\xdaH\x0bTy\xff\',\xf8o\xd4H\x16\xdd\xf4\xf4\x93\x8dw\xe6\xeap\x80\xe1p\xf8\xe7w\xb1\xb0\rp\x0c\xfd`\x94\x02\xa4$\xb0\x91\xb5\x92\xee\x845\xe3UU1)\xb05HRK\\\xd6xa\xf1\x05\xab8e\x8cr^I\x81\x94\xe2\xa1\xba\x95\x98\x92b\xe1?\xe4\xd7\xbc\x891F\xb4\'\xc1\x81\x85S\xceY\x87\x92\xe6\x0eWPJHLZT\\\x02HN\xbbw\x15`\x94\nwb\x00BI\x1c\xab\xd1B\x18g\x84\xb2xxW\x83\x12\xf0\xc6\x82.:?\xce\x86\x8c\x8cP:\xd8\xdb\x00\xa1\xc9X\x14d$\xd3\xc8fhrE6\x87\x8c\xbfpj\xa23d\xdeR\xe4\x13d\xf3h)#u?\x0bt\xc9\n\x03H\x14v\x860\xcaO\x9a\xa2\x1b\xc5\xe9\x91F\xc9\xd3cg\xb0\xa3i0=m\x02\x9d\xe1\x18\xa5f\xf4\xb3\xb6\x93\xc8\x8c\xbe\xa4\xf0j\x96\x9f\xd8\xc3FJ\x8c\xa8q\x7f\x10\xc4\xc5\x84D8\xfdJ\xdb\xe7\xab\t\xe3fr\xc5y\x97\xeb\xf9>\xd9\xe0p\xdbw\xdc`rv]\xb8\xed2?AH|\xec\xd0\x1c\xdb\x99\xe3\xfe\x14\x81\xbd\x87.\x80\xc5\xdb\x13\x04\x0e\x16}\x06\xc1v>\xac\xe4\xab\x05\x87\xcf\r\x00\xad\xb7>\x17\xe0k\rp\xb7\x9ae\x80\xe0}\xc1z9\xe3O\x16\xf9\xfe\xf3\x8e\x1c`(\'\x00\xb6v\x9b\xb8?q\xec}\xbe\xeb:P~7\x94\xdb\xb3},\xabq\x94\x06\xe5\x0c\xcb^\xea\xfc\xc0\xfc2\xf2\x94\x03\x82\x97\xae/\x00\xe7\xb5\x0b\xcf\xf3\xfe\xf0m\xfe\x03^\xe4Y\x86P\x01\xc3\xc8\x00\x00\x00\x00IEND\xaeB`\x82',
            'clock': b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\x00\x000\x08\x03\x00\x00\x00`\xdc\t\xb5\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\xc9e<\x00\x00\x00\xcfPLTEGpL\n[u\n[u\n[u\n[u\n[u\n[u\n[u\n[u\n[u\n[u\n[u\n[u\xdd\xde\xde\xe0\xe0\xe0\xeb\xeb\xeb\x0eb}\x0b\\v\xee\xee\xee\xda\xda\xda\x12f\x81\x11k\x88)\xb8\xe5\xe4\xe3\xe3\xe8\xe7\xe7\x19\x84\xa6\x15x\x97\x1d\x90\xb4\x12o\x8d\x17\x7f\xa1\x1f\x97\xbd\x16|\x9c\x14s\x92#\xa3\xcb%\xa9\xd3\xfe\xfe\xfe\x1a\x88\xab-\xc8\xf9\'\xb0\xdc(\xb4\xe1+\xbc\xea!\x9d\xc51\xdb\xf6\xc3\xcd\xd0Ex\x88p\x97\xa3\xf3\xf4\xf3\x1c\x8b\xaf\xb3\xbc\xbf\xce\xd4\xd7&\xb2\xd6`\x88\x95\xeb\x8a;\xa0\xb3\xb9 \xa5\xb9\xd6Y\x1a|||rrr\x87\x87\x877\xf3\xff[\x83\x90\xe2q\'\xe8\xc2\xa9\xe2\xa2~\xf0\xda\xca\xa9\xa9\xa9\xbahL\xbbU,\xceG\x11\xf9\x8c\xa4\x03\x00\x00\x00\x0ctRNS\x00\xaa\xd5\xfayC\x96\x85\x18(\xed\xce\x16\x99\xd2\xbe\x00\x00\x03DIDATH\xc7\xd5\x96iw\xa20\x14\x86\xebR\xb5\xed\x11\x13$`B\x82\xacVd\x11\x8a\xd8\xd6\xb1\xdb\xcc\xfc\xff\xdf47P\xea\xdav\xbe\xf6\x85#\xe1\xde\xe7=\xdc\x84\x90xq\xf1\x134\xe8\xb6n:\x18wnZ\xdd\xc1\x7f\xd0\xfd6Y\xdf-~\x81\x16wk\xd2\xee\x0f\xbe\xc1\xd1z\xf1k\x11\x04sP\x10@s\x8d\xbe\xb2t\x01_T\xf0|\xaeW\xbf\xc1\x02,\xddO\xf0\xab\x1e\x05\\?\x94\xb4\xd0\xde\xd59\xfe\x12;\'\xb8\xae\xdf\xeaz\xb0p\xf0\xe5\x19\x1e\xdd\x05\xf3[)\xd7\xa2\xb6\x86\xb1fS\xcb\xad\x02\xf3\xe0\x0e\x9d8\xae\xb0\x1b\xe82\xeb\xf8$N\xb2<M\xf3,\x89\x89\xef\xc8\x98\x1e\xb8\xf8\xb8\xaa\x9e\x15\xe83\x90I\x8a\xdc\xf3\xbc\xc9f3\x82K^\x10SF\xf5\xc0\xea\x1d\xf2}Q\xf1\xae\x88#\xcfKU5{|\xc8T5\xf5\xbc(\x16n\xe5\x10\xfd\x83\x82\xd0\xad\xee\xba\xae3-\xd2\x14pU\x1do6CyM\xbd\xb4\x98:\x90\xd2o\xd1~Q=S\xf2\xae(\xbc\xd7\xd5\xb3z \xcf+\x84\xcc\xcd\xcd\xbd\xa2\x06\x08\xaaq]?V\xbd\xe7\xa7\xd5\xeb\x91C\x8d}H\xcefh\xf7\xca\xfbt\xe68\x8eE"O\x1d\xbd<\xad\x8c\xd1\xbeT/"\x16\xa4gt\xd7\x0b\x1c\xba\x10\x81\x82\xd4\xd1h\xb2zZ\x8d\x8e\x1c\x85\x80\xb4\x1b\xe2\x8fwF\x1c\'\x0c--Je\xfe\xf5\xe9\xfe\xe5\xd0\x91F\x9a\x15\x86\x8eC\x9a\xb7\xd7\x9d\x02\x1f\xfaq:\x9aL\xe0|\xbe\xbf\x7f\x9e\xecKMc\x1f\x00g\xda\xcc\xc2\x16\r-\xcbb\x89\xfa\x0e\xbc\xfc\xfd\x93hZ\x92W\xf6\x91t$\x0c\x80\x90\xb6\xde\r\xed\xa54\x90\xb21\x18\xbf1L\xf35\xce?\x1eQ\x12iX\xb6\xdf\r\xd7&\xdcZ(\x1afc\x89O&\x89\t\x1fE`&5>\xce\x94\x08Y\x96i\x99\xd7\xef\x86\x8e)\x85\x87\x0f\x8f\x1b\xc30&\x86\xa1\xc9Q\x83QYI\x19\x10\x1e\xe2\n\xe94\x86\xe5\xbe\x01\xa4-M8\x96\xf8^jgX6\x86k\x7f\tB\xd18\x1b\xd7\x86\x84LA$\xa9\xef \x1c!I\xf8MIm\xe1\x83\xb4\xd2P\x14C1\xe0\xcc1"\x04\xe1\xc8P\xeaC)5I\x88\xa6\xd3-F)\xf5y"\xf9Z\x91\x1c\xd6H\xf9P\xc2}@X3\xac].\r,V>U\xcc\xa4\x81w?>g!\x04\xa5(\xfb\x8c\xcf\x10\xa5\x80\xec>l\xcc\xa0\x8f\x94\x17\xc3OTp\n\x00\xc3\xbb\xe9-GELQy\x16WJ\x04I\x18\xb5\xdd\xf4\x1e`\x06\x12v\x9c\x0f\xc7\xa7G\x1e\xdbB\xe6\xf1\xde\x9a\xd9#\xb6\xcd\x18\xe5\xdb\xf1\x19m9e\xb6m\x93\xde\xc1\xaa\xc4!\xc4\x04\xd9\xe65\x14=<Du+\xdf\x12!y~\xb82\xf5\x11\x071\xc1\xe3\xb2\xc2\xde\x1e\x1f\xdf\xaaF\x19s\xc1d\x0e\xf5\x8f\x162\x8dp\xc2ma\xa3m\xb6{B\xb6E\x10\x82\x04\xd1z\'K\xa5F@\x9cMm\x14\'e\x96\xe7Y\x99\xc4\xc8\x9e2.\xe3\xda\xc9R\t\x8bw\xe5\x00\x0b\x94\xa0!\x8c\x91V5%\r\xfc\xb9\xe5\x1b\x90J\x04z\x0f\x13\x81B_I\x1dA\xe7x\xb9\xa14\x96C!|~C\x91\xb3\x10\n9\x11\xc6\xdd\xaf6\xc5c\x0b\xc6\xdf\xee\xa3m\xdc\x98\xa0\xf1\xdd\xb6[\xf7\x056v`1l\xecW?\xe2\x9f\xc8?aq\x94:\x9e\xdde\x03\x00\x00\x00\x00IEND\xaeB`\x82',
            'world': b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\x00\x000\x08\x03\x00\x00\x00`\xdc\t\xb5\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\xc9e<\x00\x00\x00\xc3PLTEGpL\n[u\n[u+c6\n[s\n[u\n[u\n[u\x0b[s\n[u\x18_Y\n[u\x0f\\k"\x9f\xc7\x11g\x83\x19\x81\xa2\x91\xbcX\x88\xb2O\x16v\x95\x17{\x9b\x1b\x8a\xad\x14q\x8f\n\\v\x0fb}`\x87!Rx\x12Y\x7f\x1aKp\x0b\x1f\x96\xbb$\xa7\xd0e\x8c\'\x97\xc2_\x1b\x85\xa7Ej\x08k\x93-\x12k\x88\x1d\x8e\xb2q\x9b3\x8d\xb7T\x12m\x8a~\xa8A\x83\xacI\x9d\xcba\x1e\x91\xb6 \x9a\xc0:t44\x82_&\xaf\xdb0i8x\xa2;5yL>o \'iO+\x85~\xa8\xd9j\x1ahn0\x92\x840\x85n*\xbd\xea(\x8f\x9a x|)\xa1\xb8?\x83=\xb8\xebw=\x93Y\x80MUo\x00\x00\x00\rtRNS\x00I7\xbd\xd3\x95\xaa\x80\x1a*\xf1\xedM?>\x9d\xbc\x00\x00\x02\xfdIDATH\xc7\xdd\x95kw\xaa8\x14\x86{Q\xd1\xd3QQ\xa7\x90\x8b\x04\x13\x1a\x1a\xa9\xe1.\xe2\xa5=\xe7\xff\xff\xaa\t(\x05\n\xe72k\xcd\xa7y@\x17l\xde7\xd9\t\xac\xbd\xef\xee\xfe\x97\x8c\xb5\xd1\xc0P\x0cF\xda\xf8O\xd4\x83Y\x9e\xff\xf8H(\xa5\x1f2\xfd\xf6\x1b\xcfX;\xf8\x1f\x18p\xd7\xcb\xbe\x7f\xcft]\x00\x9a<\xfe\xc2\xa2\xa5\t\x12\x9e\xee)l\xdb\x8e\xa0\xb0\xed\xcc\x8b\x92\xc7\x9f\xc8\'\xc3#\xf6\xb2\xcc\xf3\x94N\xb8\xb6\xab\xdb\x02a\xa2\xec\xe8q\xd2\xa7\xbfO%\xd0\x8b\x91\xcb\xe1u\x9b1\xd7\xf3"\x88t/#\xe1}W\xffWH\xf4\xec*\xd5\xed-\xa4\x18E\xae\x1b1\xdf\xe7j\x08\x92v\x1c\x93\x90+\xb9\x12\x97\xa7\xb7\x88\xc0\x07Q\xe6\xacp\xb8\x82\xe4\xc6\xd7\xac\x1e\x81\xde@\r\x9a\xe9ni\x15\xd8\xc78?\xed\x86_\xf6\xe7\x02)\x17\xba\xee\xde\x0e}q\xb3.\xb6\xfchY\xc1\xe94\xd7Z\t\x99\xc1\xfb;F[\xf7\x93\xc5\xe2z\xc3\xf8\x16\xe4A`\x9d\x02\xb3\x99\xd4\xf0\xe5\x14X\xd3#[\xb8\xf5Q\x988\x038Q3X\xca\xf1\xd2Hjl\xaa1,KF\x8b6\x04\xfb\xf9\xd4\xba\x12\x04f\xfd\xca\xb5M\xa1\xb7\x8eD%R\x9d\xea\x8f\xc7\xefVM\xb0\xa9WaL\xad\xa9\xe2\x1d\xf3m\x03\x01\xcf\xd3\x06\xd6\xd4\xa8\xf4\x0f\x8eu\x8d\xe5\x92\x8b\x9b\x9a\x8b(9N[X\xceC\x95\xd1\xaa\x0c\xec\xa6\xbb\x1c\x89\x02\x86\xa9\xa4\x11\xc0\xeb\xa6\xfe\x1c_\xaa\x9cF\xf3|w#\x06@D\x02\xed\xcf\xbe\x0f\xa0\x7f\xde5\x88Y<\xba\x19\x06\x14\xed\xd7\x05\xbb\xf5\x8b\x8fA$H\x8c\x08$\x8c@y\x8d\x97$\x9c\x0en\x86\xa7=\xbc=x[\xaf\xcf\x98G\x11\x13\\\xc6\x141\x06k\x87d\xf0[\xb5Io\xfb\xb7\x1a?\x81\x80p\xc6\xf0\xf9(e\xe3\x01\xe5\xb5\xe1\xa5\xcd>\x96\x88p\xe8\xc7\x18&\xd2\xdf\xdc\xa2\x92\xe0\xca\xf0\xf4w\x87\xa3\x04\x00\x10!"N\xe4\xf1\x1a\xf2\x91\xffT-z\xde1l\xf6\x12"\xc6\x19\xe7\x11Cq\xf9|NW\xd5\xa2G\xcbM\x0f1d\n\xa2< .\x03\xf3e\xb5\xad\xda\xeb\xbc\x07\xaa\xf6\xb5Dm/\x95\x17\x15y\xad^\xdc\x83\xd9\xa3_bRQL"U\xc8|\xf8\xfc\xf8V].\x184IT\xc8\xa8?o\xa7\xc7\x11\xc2\x86\x1e\xa7\xab\x95S\x7f\xdecc\xd9\xe5\x82\xd1\'0Q\x01\xa3Q3\x87N\x8f#\x84J\n\xca\x1fN\x97K\xa7Y7&\xc6s\x97KJ\xab\tBu\xdb\xaeL\x9a\xd9\xe38PXB\xc3\xc3\xf3\xb3\xa9\xb5\x0b\xd3p\xf6\xda!\xc5\x10"e\x08\xd5\xf5l\xf8\xb5T\x1a3\xe7+!.\xc6\xc7\xe1\xc1qf\x9dRywo\xcc\xda8\xd7\x8cT>\xea\xc6\xe8)\xdf\xf7\x86\xd9v\xa8\x8c0\xa6\xa1\xba2\xfb\xf4ECiYL\x8a\x95\x9e\x1e\x94|8\xf9Y\xcb2\x0c\xf3\x93\x03-\xf5\xa6ah\xbfj\x8a\rKJU\xfeJ\xfe\xbb>Z\xf4\xe8\xd2P\xf6\xea?k\xd5\xff\xa6\xb1\xff\xf7\xfc\x03\xc8\xf8\x9d9\'\xf7\x868\x00\x00\x00\x00IEND\xaeB`\x82'
        }[last_content_json['text']]
        data = {
            'username': login['username'],
            'password': login['password'],
            'remember': 1,
            'captchaSelection': next(hash for hash in last_content_json['images'] if self.request(entry, 'get',
                                                                                                  urljoin(entry['url'],
                                                                                                          '/simpleCaptcha.php?hash=' + hash)).content == target),
            'submitme': 'X',
            'returnto': '/'
        }
        return self.request(entry, 'post', work.url, data=data)



from typing import Final

# Removed reseed functionality
from ..schema.nexusphp import Attendance
from ..utils import net_utils


class MainClass(Attendance):
    URL: Final = 'https://ptcafe.club/'
    USER_CLASSES: Final = {
        'downloaded': [805306368000, 3298534883328],
        'share_ratio': [3.05, 4.55],
        'points': [400000, 1000000],
        'days': [280, 700]
    }

    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        net_utils.dict_merge(selector, {
            'details': {
                'points': {
                    'regex': r'做种积分.*?([\d,.]+)'
                },
            }
        })
        return selector



import json
from pathlib import Path

RECORD_FILE_PATH = 'reseed'


def load_record(site_name: str) -> dict:
    record_file = Path(f'{RECORD_FILE_PATH}/{site_name}.json')
    return json.loads(record_file.read_text()) if record_file.is_file() else {}


def save_record(site_name: str, record: dict) -> None:
    Path(RECORD_FILE_PATH).mkdir(exist_ok=True)
    record_file = Path(f'{RECORD_FILE_PATH}/{site_name}.json')
    record_file.touch(exist_ok=True)
    record_file.write_text(json.dumps(record))



from typing import Final

from ..core.entry import SignInEntry
from ..base.sign_in import SignState
from ..base.sign_in import check_final_state
from ..base.work import Work
from ..schema.private_torrent import PrivateTorrent
from ..utils.net_utils import get_module_name
from ..utils.value_handler import handle_infinite, handle_join_date


class MainClass(PrivateTorrent):
    URL: Final = 'https://www.gaytor.rent/'
    USER_CLASSES: Final = {
        'downloaded': [858993459200],
        'share_ratio': [1.05],
        'days': [28]
    }

    @classmethod
    def sign_in_build_schema(cls) -> dict:
        return {
            get_module_name(cls): {
                'type': 'object',
                'properties': {
                    'login': {
                        'type': 'object',
                        'properties': {
                            'username': {'type': 'string'},
                            'password': {'type': 'string'}
                        },
                        'additionalProperties': False
                    }
                },
                'additionalProperties': False
            }
        }

    def sign_in_build_login_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/takelogin.php',
                method=self.sign_in_by_login,
                succeed_regex=['Logout'],
                assert_state=(check_final_state, SignState.SUCCEED),
                is_base_content=True,
                response_urls=['/']
            )
        ]

    def sign_in_build_login_data(self, login: dict, last_content: str) -> dict:
        return {
            'username': login['username'],
            'password': login['password'],
            'sw': '1920:1080'
        }

    @property
    def details_selector(self) -> dict:
        return {
            'user_id': r'id=(\d+)"><i class="icon-tools"></i> Details',
            'detail_sources': {
                'default': {
                    'link': '/userdetails.php?id={}',
                    'elements': {
                        'bar': '#navbar li.dropdown.text-nowrap li:nth-child(8) > a',
                        'table': 'div:nth-child(2) table:nth-child(11) > tbody'
                    }
                }
            },
            'details': {
                'uploaded': {
                    'regex': r'Uploaded.*?([\d.]+ [ZEPTGMK]?B)'
                },
                'downloaded': {
                    'regex': r'Downloaded.*?([\d.]+ [ZEPTGMK]?B)'
                },
                'share_ratio': {
                    'regex': r'Share ratio.*?(∞|[\d,.]+)',
                    'handle': handle_infinite
                },
                'points': {
                    'regex': r'Total Seed Bonus([\d,.]+)'
                },
                'join_date': {
                    'regex': r'Join\sdate\s*?(\d{4}-\d{2}-\d{2})',
                    'handle': handle_join_date
                },
                'seeding': {
                    'regex': r'\s*([\d,]+)'
                },
                'leeching': {
                    'regex': r'\s*[\d,]+\s*([\d,]+)'
                },
                'hr': None
            }
        }



from __future__ import annotations

import re
from typing import Final
from urllib.parse import urljoin

from requests import Response

from ..core.entry import SignInEntry
from ..base.request import check_network_state, NetworkState
# Removed reseed functionality
from ..base.sign_in import check_final_state, SignState, Work
from ..schema.discuz import Discuz
from ..utils import google_auth
from ..utils.net_utils import get_module_name


class MainClass(Discuz):
    URL: Final = 'https://skyeysnow.com/'
    USER_CLASSES: Final = {
        'points': [1000000]
    }

    @classmethod
    def sign_in_build_schema(cls) -> dict:
        return {
            get_module_name(cls): {
                'type': 'object',
                'properties': {
                    'login': {
                        'type': 'object',
                        'properties': {
                            'username': {'type': 'string'},
                            'password': {'type': 'string'},
                            'secret_key': {'type': 'string'},
                        },
                        'additionalProperties': False
                    }
                },
                'additionalProperties': False
            }
        }

    def sign_in_build_login_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/login.php',
                method=self.sign_in_by_get,
                assert_state=(check_network_state, NetworkState.SUCCEED),
            ),
            Work(
                url='/login.php',
                method=self.sign_in_by_login,
                assert_state=(check_network_state, NetworkState.SUCCEED),
                login_url_regex='(?<=action=").*?(?=")',
                formhash_regex='(?<="formhash" value=").*(?=")'
            )
        ]

    def sign_in_build_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/',
                method=self.sign_in_by_get,
                succeed_regex=['<a.*?title="访问我的空间">.*?</a>'],
                assert_state=(check_final_state, SignState.SUCCEED),
                use_last_content=True,
                is_base_content=True
            )
        ]

    def sign_in_by_login(self, entry: SignInEntry, config: dict, work: Work, last_content: str) -> Response | None:
        if not (login := entry['site_config'].get('login')):
            entry.fail_with_prefix('Login data not found!')
            return None

        secret_key = login.get('secret_key')
        username, password = login['username'], login['password']

        if secret_key:
            totp_code = google_auth.calc(secret_key)
            username += '@' + totp_code

        login_url = urljoin(entry['url'], re.search(work.login_url_regex, last_content).group())
        work.response_urls = [login_url]
        formhash = re.search(work.formhash_regex, last_content).group()
        data = {
            'formhash': formhash,
            'referer': '/',
            'loginfield': 'username',
            'username': username,
            'password': password,
            'loginsubmit': 'true'
        }
        return self.request(entry, 'post', login_url, data=data, verify=False)



from __future__ import annotations

from typing import Final
from urllib.parse import urljoin

from flexget.entry import Entry

from ..core.entry import SignInEntry
from ..base.request import check_network_state, NetworkState
# Removed reseed functionality
from ..base.sign_in import SignState
from ..base.sign_in import check_final_state
from ..base.work import Work
from ..schema.gazelle import Gazelle
from ..utils import net_utils
from ..utils.net_utils import get_module_name


class MainClass(Gazelle, Reseed):
    URL: Final = 'https://dicmusic.com/'
    USER_CLASSES: Final = {
        'uploaded': [26843545600, 1319413953331],
        'share_ratio': [1.05, 1.05],
        'days': [14, 112]
    }

    @classmethod
    def sign_in_build_schema(cls) -> dict:
        return {
            get_module_name(cls): {
                'type': 'object',
                'properties': {
                    'cookie': {'type': 'string'},
                    'login': {
                        'type': 'object',
                        'properties': {
                            'username': {'type': 'string'},
                            'password': {'type': 'string'}
                        },
                        'additionalProperties': False
                    }
                },
                'additionalProperties': False
            }
        }

    @classmethod
    def sign_in_build_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/',
                method=self.sign_in_by_get,
                succeed_regex=['积分 \\(.*?\\)'],
                assert_state=(check_final_state, SignState.SUCCEED),
                is_base_content=True
            )
        ]

    def sign_in_build_login_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/login.php',
                method=self.sign_in_by_login,
                assert_state=(check_network_state, NetworkState.SUCCEED),
                response_urls=['/index.php']
            )
        ]

    def sign_in_build_login_data(self, login: dict, last_content: str) -> dict:
        return {
            'username': login['username'],
            'password': login['password'],
            'keeplogged': 1,
            'login': '登录',
        }

    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        net_utils.dict_merge(selector, {
            'detail_sources': {
                'default': {
                    'elements': {'table': 'div.box.box_info.box_userinfo_stats > ul'}
                },
                'extend': {
                    'link': '/ajax.php?action=community_stats&userid={}'
                }
            }
        })
        return selector

    @classmethod
    


from __future__ import annotations

import re
from typing import Final
from urllib.parse import urljoin

from requests import Response

from ..core.entry import SignInEntry
# Removed reseed functionality
from ..base.sign_in import check_final_state, SignState, Work
from ..schema.nexusphp import Attendance


class MainClass(Attendance):
    URL: Final = 'https://1ptba.com/'
    USER_CLASSES: Final = {
        'downloaded': [805306368000, 3298534883328],
        'share_ratio': [3.05, 4.55],
        'days': [280, 700]
    }

    def sign_in_build_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/attendance.php',
                method=self.sign_in_by_param,
                succeed_regex=[
                    '这是您的第.*?次签到，已连续签到.*?天，本次签到获得.*?魔力值。|這是您的第.*次簽到，已連續簽到.*?天，本次簽到獲得.*?魔力值。',
                    '[签簽]到已得\\d+',
                    '您今天已经签到过了，请勿重复刷新。|您今天已經簽到過了，請勿重複刷新。'],
                assert_state=(check_final_state, SignState.SUCCEED),
                is_base_content=True
            )
        ]

    def sign_in_by_param(self, entry: SignInEntry, config: dict, work: Work,
                         last_content: str = None) -> Response | None:
        if response := self.request(entry, 'get', work.url):
            if location_match := re.search('window\\.location="(.*?);</script>', response.text):
                uri: str = re.sub('["+ ]', '', location_match.group(1))
                work.url = urljoin(work.url, uri)
                return self.sign_in_by_get(entry, config, work, last_content)
            return response
        return None



from typing import Final

from ..core.entry import SignInEntry
# Removed reseed functionality
from ..schema.nexusphp import AttendanceHR


class MainClass(AttendanceHR):
    URL: Final = 'https://carpt.net/'
    IGNORE_TITLE = r'H&R\(ID: \d+\) 已达标'
    USER_CLASSES: Final = {
        'downloaded': [805306368000, 3298534883328],
        'share_ratio': [6, 9],
        'days': [280, 700]
    }

    def get_messages(self, entry: SignInEntry, config: dict) -> None:
        self.get_nexusphp_messages(entry, config, ignore_title=self.IGNORE_TITLE)



from typing import Final

# Removed reseed functionality
from ..schema.nexusphp import VisitHR
from ..utils import net_utils


class MainClass(VisitHR):
    URL: Final = 'https://ptsbao.club/'
    USER_CLASSES: Final = {
        'downloaded': [805306368000, 3298534883328],
        'share_ratio': [3.05, 4.55],
        'days': [112, 364]
    }

    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        net_utils.dict_merge(selector, {
            'details': {
                'uploaded': {
                    'regex': r'上传量:  ([\d,.]+ [ZEPTGMK]?B)'
                },
                'downloaded': {
                    'regex': r'下载量:  ([\d,.]+ [ZEPTGMK]?B)'
                },
                'points': {
                    'regex': '魔力值.*?：([\\d,.]+)'
                }
            }
        })
        return selector



from typing import Final

# Removed reseed functionality
from ..schema.nexusphp import Attendance


class MainClass(Attendance):
    URL: Final = 'https://hdtime.org/'
    USER_CLASSES: Final = {
        'downloaded': [1649267441664, 10995116277760],
        'share_ratio': [3.05, 4.55],
        'days': [280, 700]
    }



from typing import Final

# Removed reseed functionality
from ..schema.nexusphp import Visit
from ..utils import net_utils


class MainClass(Visit):
    URL: Final = 'https://www.joyhd.net/'
    USER_CLASSES: Final = {
        'downloaded': [644245094400, 5368709120000],
        'share_ratio': [4.5, 6],
        'days': [175, 350]
    }

    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        net_utils.dict_merge(selector, {
            'details': {
                'points': {
                    'regex': '银元.*?([\\d,.]+)'
                }
            }
        })
        return selector



from __future__ import annotations

from time import sleep
from typing import Final

from requests import Response

from ..core.entry import SignInEntry
# Removed reseed functionality
from ..schema.nexusphp import AttendanceHR


class MainClass(AttendanceHR):
    URL: Final = 'https://pt.soulvoice.club/'
    USER_CLASSES: Final = {
        'downloaded': [805306368000, 3298534883328],
        'share_ratio': [3.05, 4.55],
        'days': [280, 700]
    }

    def request(self,
                entry: SignInEntry,
                method: str,
                url: str,
                **kwargs,
                ) -> Response | None:
        sleep(2)
        return super().request(entry, method, url, **kwargs)



"""
FlareSolverr集成模块
用于绕过Cloudflare保护和处理JavaScript渲染页面
"""

from __future__ import annotations

import json
import time
from typing import Optional, Dict, Any
from urllib.parse import urljoin

import requests
from loguru import logger

from ..core.entry import SignInEntry


class FlareSolverrClient:
    """FlareSolverr客户端"""
    
    def __init__(self, server_url: str, timeout: int = 60):
        """
        初始化FlareSolverr客户端
        
        Args:
            server_url: FlareSolverr服务器地址，如 http://localhost:8191
            timeout: 请求超时时间（秒）
        """
        self.server_url = server_url.rstrip('/')
        self.timeout = timeout
        self.session_id = None
    
    def create_session(self, proxy: Optional[str] = None) -> bool:
        """
        创建浏览器会话
        
        Args:
            proxy: 代理设置，格式如 http://proxy:port
            
        Returns:
            bool: 是否创建成功
        """
        try:
            data = {
                "cmd": "sessions.create",
                "proxy": proxy
            }
            
            response = requests.post(
                f"{self.server_url}/v1",
                json=data,
                timeout=self.timeout
            )
            
            if response.status_code == 200:
                result = response.json()
                if result.get("status") == "ok":
                    self.session_id = result.get("session")
                    logger.info(f"FlareSolverr session created: {self.session_id}")
                    return True
            
            logger.error(f"Failed to create FlareSolverr session: {response.text}")
            return False
            
        except Exception as e:
            logger.error(f"FlareSolverr session creation error: {e}")
            return False
    
    def destroy_session(self) -> bool:
        """销毁浏览器会话"""
        if not self.session_id:
            return True
            
        try:
            data = {
                "cmd": "sessions.destroy",
                "session": self.session_id
            }
            
            response = requests.post(
                f"{self.server_url}/v1",
                json=data,
                timeout=self.timeout
            )
            
            if response.status_code == 200:
                result = response.json()
                if result.get("status") == "ok":
                    logger.info(f"FlareSolverr session destroyed: {self.session_id}")
                    self.session_id = None
                    return True
            
            logger.error(f"Failed to destroy FlareSolverr session: {response.text}")
            return False
            
        except Exception as e:
            logger.error(f"FlareSolverr session destruction error: {e}")
            return False
    
    def request_get(self, url: str, headers: Optional[Dict[str, str]] = None,
                   cookies: Optional[Dict[str, str]] = None,
                   max_timeout: int = 60000) -> Optional[Dict[str, Any]]:
        """
        通过FlareSolverr发送GET请求

        Args:
            url: 目标URL
            headers: 请求头（FlareSolverr v2中已移除，仅保留兼容性）
            cookies: Cookie字典
            max_timeout: 最大超时时间（毫秒）

        Returns:
            Dict: 包含响应内容的字典，或None如果失败
        """
        try:
            data = {
                "cmd": "request.get",
                "url": url,
                "maxTimeout": max_timeout
            }

            if self.session_id:
                data["session"] = self.session_id

            # FlareSolverr v2移除了headers参数，不再添加
            # if headers:
            #     data["headers"] = headers

            if cookies:
                data["cookies"] = [
                    {"name": k, "value": v} for k, v in cookies.items()
                ]
            
            response = requests.post(
                f"{self.server_url}/v1",
                json=data,
                timeout=self.timeout
            )
            
            if response.status_code == 200:
                result = response.json()
                if result.get("status") == "ok":
                    return result.get("solution", {})
            
            logger.error(f"FlareSolverr request failed: {response.text}")
            return None
            
        except Exception as e:
            logger.error(f"FlareSolverr request error: {e}")
            return None
    
    def request_post(self, url: str, post_data: str,
                    headers: Optional[Dict[str, str]] = None,
                    cookies: Optional[Dict[str, str]] = None,
                    max_timeout: int = 60000) -> Optional[Dict[str, Any]]:
        """
        通过FlareSolverr发送POST请求

        Args:
            url: 目标URL
            post_data: POST数据（字符串格式）
            headers: 请求头（FlareSolverr v2中已移除，仅保留兼容性）
            cookies: Cookie字典
            max_timeout: 最大超时时间（毫秒）

        Returns:
            Dict: 包含响应内容的字典，或None如果失败
        """
        try:
            data = {
                "cmd": "request.post",
                "url": url,
                "postData": post_data,
                "maxTimeout": max_timeout
            }

            if self.session_id:
                data["session"] = self.session_id

            # FlareSolverr v2移除了headers参数，不再添加
            # if headers:
            #     data["headers"] = headers

            if cookies:
                data["cookies"] = [
                    {"name": k, "value": v} for k, v in cookies.items()
                ]
            
            response = requests.post(
                f"{self.server_url}/v1",
                json=data,
                timeout=self.timeout
            )
            
            if response.status_code == 200:
                result = response.json()
                if result.get("status") == "ok":
                    return result.get("solution", {})
            
            logger.error(f"FlareSolverr POST request failed: {response.text}")
            return None
            
        except Exception as e:
            logger.error(f"FlareSolverr POST request error: {e}")
            return None


def cookie_str_to_dict(cookie_str: str) -> Dict[str, str]:
    """将cookie字符串转换为字典格式"""
    cookie_dict = {}
    for item in cookie_str.split(';'):
        if '=' in item:
            key, value = item.split('=', 1)
            cookie_dict[key.strip()] = value.strip()
    return cookie_dict


def get_flaresolverr_client(config: dict) -> Optional[FlareSolverrClient]:
    """
    从配置中获取FlareSolverr客户端
    
    Args:
        config: 配置字典
        
    Returns:
        FlareSolverrClient: 客户端实例，或None如果未配置
    """
    flaresolverr_config = config.get('flaresolverr')
    if not flaresolverr_config:
        return None
    
    if isinstance(flaresolverr_config, str):
        # 简单字符串配置，仅包含服务器URL
        return FlareSolverrClient(flaresolverr_config)
    elif isinstance(flaresolverr_config, dict):
        # 详细配置
        server_url = flaresolverr_config.get('server_url')
        if not server_url:
            return None
        
        timeout = flaresolverr_config.get('timeout', 60)
        return FlareSolverrClient(server_url, timeout)
    
    return None


def should_use_flaresolverr(entry: SignInEntry, config: dict) -> bool:
    """
    判断是否应该使用FlareSolverr
    
    Args:
        entry: 签到条目
        config: 配置字典
        
    Returns:
        bool: 是否使用FlareSolverr
    """
    flaresolverr_config = config.get('flaresolverr')
    if not flaresolverr_config:
        return False
    
    # 检查全局启用设置
    if isinstance(flaresolverr_config, dict):
        # 检查是否全局启用
        if flaresolverr_config.get('enable_all', False):
            return True
        
        # 检查站点特定设置
        enabled_sites = flaresolverr_config.get('enabled_sites', [])
        site_name = entry.get('site_name', '')
        return site_name in enabled_sites
    
    # 如果是字符串配置，默认不启用（需要在站点配置中明确指定）
    return False



from typing import Final

# Removed reseed functionality
from ..schema.nexusphp import AttendanceHR


class MainClass(AttendanceHR):
    URL: Final = 'https://ptchina.org/'
    USER_CLASSES: Final = {
        'downloaded': [805_306_368_000, 3_298_534_883_328],
        'share_ratio': [3.05, 4.55],
        'days': [280, 700]
    }



from typing import Final

# Removed reseed functionality
from ..schema.nexusphp import Visit
from ..utils import net_utils
from ..utils.value_handler import size


class MainClass(Visit):
    URL: Final = 'https://springsunday.net/'
    USER_CLASSES: Final = {
        'downloaded': [size(2, 'TiB'), size(11.5, 'TiB')],
        'share_ratio': [1.2, 2],
        'points': [400000, 2300000],
    }

    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        net_utils.dict_merge(selector, {
            'detail_sources': {
                'default': {
                    'do_not_strip': True,
                    'elements': {
                        'bar': '#info_block > div:nth-child(1) > span',
                        'table': '#outer div.main:last-child'
                    }
                }
            },
            'details': {
                'points': {
                    'regex': r'做种积分.*?([\d.,]+?[ZEPTGMK])',
                }
            }
        })
        return selector



from typing import Final

from ..core.entry import SignInEntry
# Removed reseed functionalityCookie
from ..base.sign_in import check_final_state, SignState
from ..base.work import Work
from ..schema.nexusphp import AttendanceHR
from ..utils import net_utils
from ..utils.value_handler import size


class MainClass(AttendanceHR):
    URL: Final = 'https://www.hddolby.com/'
    USER_CLASSES: Final = {
        'downloaded': [size(2, 'TiB'), size(8, 'TiB')],
        'share_ratio': [4.5, 5.5],
        'points': [720000, 1680000],
        'days': [194, 392]
    }

    def sign_in_build_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/attendance.php',
                method=self.sign_in_by_get,
                succeed_regex=[
                    '这是您的第.*?次签到，已连续签到.*?天，本次签到获得.*个鲸币。',
                    '签到已得\\d+',
                    '您今天已经签到过了，请勿重复刷新。|您今天已經簽到過了，請勿重複刷新。'],
                assert_state=(check_final_state, SignState.SUCCEED),
                is_base_content=True
            )
        ]

    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        net_utils.dict_merge(selector, {
            'details': {
                'points': {
                    'regex': r'做种积分.*?([\d,.]+)'
                }
            }
        })
        return selector



from typing import Final

from ..core.entry import SignInEntry
# Removed reseed functionality
from ..base.sign_in import check_final_state, SignState, check_sign_in_state
from ..base.work import Work
from ..schema.nexusphp import NexusPHP
from ..utils import net_utils


class MainClass(NexusPHP):
    URL: Final = 'https://totheglory.im/'
    USER_CLASSES: Final = {
        'uploaded': [769658139444, 109951162777600],
        'downloaded': [3848290697216, 10995116277760],
        'share_ratio': [5, 6],
        'days': [224, 336]
    }

    DATA = {
        'signed_timestamp': '(?<=signed_timestamp: ")\\d{10}',
        'signed_token': '(?<=signed_token: ").*(?=")'
    }

    def sign_in(self, entry: SignInEntry, config: dict) -> None:
        entry.fail_with_prefix("公告禁止使用脚本，请移除")
        return

    def sign_in_build_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/',
                method=self.sign_in_by_get,
                succeed_regex=['<b style="color:green;">已签到</b>'],
                assert_state=(check_sign_in_state, SignState.NO_SIGN_IN),
                is_base_content=True
            ),
            Work(
                url='/signed.php',
                method=self.sign_in_by_post,
                data=self.DATA,
                succeed_regex=['您已连续签到\\d+天，奖励\\d+积分，明天继续签到将获得\\d+积分奖励。'],
                assert_state=(check_final_state, SignState.SUCCEED),
            )
        ]

    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        net_utils.dict_merge(selector, {
            'detail_sources': {
                'default': {
                    'elements': {
                        'bar': 'body > table:nth-child(3) > tbody > tr > td > table > tbody > tr > td:nth-child(1)',
                        'table': '#main_table > tbody > tr:nth-child(1) > td > table > tbody > tr > td > table > tbody'
                    }
                }
            },
            'details': {
                'uploaded': {
                    'regex': ('(上[传傳]量|Uploaded).+?([\\d.]+ ?[ZEPTGMk]?i?B)', 2),
                    'handle': self.handle_size
                },
                'downloaded': {
                    'regex': ('(下[载載]量|Downloaded).+?([\\d.]+ ?[ZEPTGMk]?i?B)', 2),
                    'handle': self.handle_size
                },
                'points': {
                    'regex': '积分.*?([\\d,.]+)'
                },
                'seeding': {
                    'regex': '做种活动.*?(\\d+)'
                },
                'leeching': {
                    'regex': '做种活动.*?\\d+\\D+(\\d+)'
                },
                'hr': {
                    'regex': 'HP.*?(\\d+)',
                    'handle': self.handle_hr
                }
            }
        })
        return selector

    def handle_size(self, size: str) -> str:
        return size.upper()

    def handle_hr(self, hr: str) -> str:
        return str(15 - int(hr))



from typing import Final

from ..core.entry import SignInEntry
from ..base.sign_in import check_final_state, SignState, Work
from ..schema.private_torrent import PrivateTorrent
from ..utils.net_utils import get_module_name


class MainClass(PrivateTorrent):
    URL: Final = 'https://ninjacentral.co.za/'

    @classmethod
    def sign_in_build_schema(cls) -> dict:
        return {
            get_module_name(cls): {
                'type': 'object',
                'properties': {
                    'login': {
                        'type': 'object',
                        'properties': {
                            'username': {'type': 'string'},
                            'password': {'type': 'string'}
                        },
                        'additionalProperties': False
                    }
                },
                'additionalProperties': False
            }
        }

    def sign_in_build_login_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/login',
                method=self.sign_in_by_login,
                succeed_regex=['Logout'],
                assert_state=(check_final_state, SignState.SUCCEED),
                is_base_content=True,
                response_urls=['/']
            )
        ]

    def sign_in_build_login_data(self, login: dict, last_content: str) -> dict:
        return {
            'redirect': '',
            'username': login['username'],
            'password': login['password'],
            'rememberme': 'on'
        }

    @property
    def details_selector(self) -> dict:
        return {
            'detail_sources': {
                'default': {
                    'do_not_strip': True,
                    'link': '/profile',
                    'elements': {
                        'table': '#content > div > div > table:nth-child(1) > tbody > tr:nth-child(3) > td',
                    }
                }
            },
            'details': {
                'uploaded': None,
                'downloaded': None,
                'share_ratio': None,
                'points': None,
                'join_date': {
                    'regex': r'''(?x)(\d {4} - \d {2} - \d {2})'''
                },
                'seeding': None,
                'leeching': None,
                'hr': None
            }
        }



from typing import Final

from ..core.entry import SignInEntry
from ..schema.xbtit import XBTIT
from ..utils import net_utils
from ..utils.value_handler import handle_infinite


class MainClass(XBTIT):
    URL: Final = 'https://hd-space.org/'
    SUCCEED_REGEX: Final = 'Welcome back .*?</span> '
    USER_CLASSES: Final = {
        'uploaded': [2199023255552],
        'share_ratio': [4.25]
    }

    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        net_utils.dict_merge(selector, {
            'user_id': 'index.php\\?page=usercp&amp;uid=(\\d+)',
            'detail_sources': {
                'default': {
                    'link': '/index.php?page=usercp&uid={}',
                    'elements': {
                        'bar': 'table.lista table.lista',
                        'table': 'body > div:nth-child(2) > table > tbody > tr > td > table > tbody > tr > td > table > tbody > tr > td > table > tbody > tr > td > table > tbody > tr > td > table:nth-child(9) > tbody > tr:nth-child(2) > td > table:nth-child(2) > tbody > tr > td:nth-child(4) > table'
                    }
                }
            },
            'details': {
                'uploaded': {
                    'regex': 'UP: ([\\d.]+ [ZEPTGMK]B)'
                },
                'downloaded': {
                    'regex': 'DL:  ([\\d.]+ [ZEPTGMK]B)'
                },
                'share_ratio': {
                    'regex': 'Ratio: (---|[\\d.]+)',
                    'handle': handle_infinite

                },
                'points': {
                    'regex': 'Bonus: (---|[\\d,.]+)',
                    'handle': handle_infinite
                },
                'join_date': {
                    'regex': 'Joined on.{5}(.*?\\d{4})',
                    'handle': self.handle_join_date
                },
                'seeding': None,
                'leeching': None,
                'hr': None
            }

        })
        return selector

    def get_messages(self, entry: SignInEntry, config: dict) -> None:
        self.get_XBTIT_message(entry, config,
                               MESSAGES_URL_REGEX='index.php\\?page=usercp&amp;uid=\\d+&amp;do=pm&amp;action=list')



#!/usr/bin/env python3
"""
PT签到工具 - 简化版CLI
"""
import click
from loguru import logger
from .core.config_manager import ConfigManager


@click.group()
@click.option('-c', '--config', default='config.yml', help='配置文件路径')
@click.option('-v', '--verbose', is_flag=True, help='详细日志输出')
@click.pass_context
def cli(ctx, config: str, verbose: bool):
    """PT站点自动签到工具"""
    # 设置日志级别
    logger.remove()  # 移除默认处理器
    if verbose:
        logger.add(lambda msg: print(msg, end=''), level="DEBUG")
    else:
        logger.add(lambda msg: print(msg, end=''), level="INFO")

    # 初始化配置管理器
    try:
        config_manager = ConfigManager(config)
        ctx.ensure_object(dict)
        ctx.obj['config_manager'] = config_manager
        logger.info("程序初始化完成")
    except Exception as e:
        logger.error(f"初始化失败: {e}")
        ctx.exit(1)


# ==================== 核心命令 ====================

@cli.command()
@click.option('--site', '-s', help='仅签到指定站点')
@click.option('--force', is_flag=True, help='强制重新签到')
@click.option('--dry-run', is_flag=True, help='模拟运行')
@click.pass_context
def run(ctx, site: str, force: bool, dry_run: bool):
    """执行签到任务"""
    config_manager = ctx.obj['config_manager']
    
    if dry_run:
        logger.info("模拟运行模式，不会实际执行签到")
    
    # 创建调度器并执行
    from .core.scheduler import TaskScheduler
    scheduler = TaskScheduler(config_manager)
    
    # 设置强制选项
    force_options = {}
    if force:
        force_options['force_all'] = True
    if site:
        force_options['force_sites'] = [site]
    
    try:
        if dry_run:
            logger.info("模拟运行完成")
        else:
            scheduler.run_once(force_options)
    except Exception as e:
        logger.error(f"签到任务执行失败: {e}")
        ctx.exit(1)


# ==================== 测试命令 ====================

@cli.command()
@click.pass_context
def test(ctx):
    """测试配置文件"""
    config_manager = ctx.obj['config_manager']
    
    logger.info("=== 配置文件测试 ===")
    
    # 测试站点配置
    sites = config_manager.get_sites()
    logger.info(f"配置的站点数量: {len(sites)}")
    
    for site_name in sites.keys():
        logger.info(f"  - {site_name}")
    
    # 测试百度OCR配置
    baidu_ocr = config_manager.get_baidu_ocr_config()
    if baidu_ocr and baidu_ocr.get('app_id'):
        logger.info("百度OCR配置: 已配置")
    else:
        logger.info("百度OCR配置: 未配置")
    
    logger.info("配置文件测试完成")


@cli.command()
@click.argument('site_name')
@click.option('--debug', is_flag=True, help='启用调试模式')
@click.pass_context
def test_site(ctx, site_name: str, debug: bool):
    """测试单个站点"""
    config_manager = ctx.obj['config_manager']
    
    if debug:
        logger.debug("启用调试模式")
    
    # 检查站点配置
    sites = config_manager.get_sites()
    if site_name not in sites:
        logger.error(f"站点 {site_name} 未在配置文件中找到")
        ctx.exit(1)
    
    logger.info(f"测试站点 {site_name} 签到...")
    
    if debug:
        site_config = sites[site_name]
        logger.debug(f"站点配置: {site_config}")
    
    # 创建调度器并执行单站点测试
    from .core.scheduler import TaskScheduler
    scheduler = TaskScheduler(config_manager)
    
    # 临时修改配置只包含指定站点
    original_sites = config_manager.config['sites']
    config_manager.config['sites'] = {site_name: sites[site_name]}
    
    try:
        scheduler.run_once()
    finally:
        # 恢复原始配置
        config_manager.config['sites'] = original_sites


# ==================== 状态命令 ====================

@cli.command()
@click.option('--clear', is_flag=True, help='清除今日签到状态')
@click.option('--clear-site', help='清除指定站点状态')
@click.option('--show-failed', is_flag=True, help='显示失败统计')
@click.pass_context
def status(ctx, clear: bool, clear_site: str, show_failed: bool):
    """查看和管理签到状态"""
    from .core.signin_status import SignInStatusManager
    
    status_manager = SignInStatusManager()
    
    if clear:
        status_manager.clear_today_status()
        logger.info("已清除今日所有签到状态")
        return
    
    if clear_site:
        status_manager.clear_site_status(clear_site)
        logger.info(f"已清除站点 {clear_site} 的今日签到状态")
        return
    
    # 显示状态
    logger.info("=== 今日签到状态 ===")

    summary = status_manager.get_today_summary()
    if summary['total'] == 0:
        logger.info("今日暂无签到记录")
        return

    for site_name, status_info in summary['sites'].items():
        status_text = "✅ 成功" if status_info['status'] == 'success' else "❌ 失败"
        message = status_info.get('message', '')
        time_str = status_info.get('time', '')
        logger.info(f"  {site_name}: {status_text} - {message} ({time_str})")
    
    if show_failed:
        logger.info("\n=== 失败次数统计 ===")
        failed_counts = status_manager.get_all_failed_counts()
        if failed_counts:
            for site_name, count in failed_counts.items():
                if count > 0:
                    logger.info(f"  {site_name}: {count} 次")
        else:
            logger.info("暂无失败记录")


# ==================== 通知命令 ====================

@cli.command()
@click.option('--format', '-f', type=click.Choice(['text', 'json']), default='text', help='输出格式')
@click.option('--title-only', is_flag=True, help='仅返回标题')
@click.option('--detailed', '-d', is_flag=True, help='显示详细信息（包含消息和详情）')
@click.pass_context
def get_notification(ctx, format: str, title_only: bool, detailed: bool):
    """获取最新签到结果通知消息"""
    # 使用便捷函数获取通知消息
    notification = get_notification_message(include_details=detailed)

    if not notification['has_data']:
        if format == 'json':
            import json
            result = {'title': '', 'content': '', 'has_data': False}
            print(json.dumps(result, ensure_ascii=False))
        else:
            print("")  # 空输出表示无数据
        return

    if title_only:
        print(notification['title'])
        return

    if format == 'json':
        import json
        result = {
            'title': notification['title'],
            'content': notification['content'],
            'has_data': True,
            'summary': notification['summary']
        }
        print(json.dumps(result, ensure_ascii=False))
    else:
        print(f"标题: {notification['title']}")
        print(f"内容:\n{notification['content']}")


# ==================== 调试命令 ====================

@cli.command()
@click.option('--site', '-s', help='调试指定站点')
@click.option('--show-config', is_flag=True, help='显示配置信息')
@click.pass_context
def debug(ctx, site: str, show_config: bool):
    """调试模式"""
    config_manager = ctx.obj['config_manager']

    logger.info("=== 调试信息 ===")

    if show_config:
        logger.info("完整配置信息:")
        import json
        config_str = json.dumps(config_manager.config, indent=2, ensure_ascii=False)
        # 隐藏敏感信息
        config_str = config_str.replace('"cookie":', '"cookie": "[HIDDEN]",')
        logger.info(config_str)
        return

    # 显示站点概览
    sites = config_manager.get_sites()
    logger.info(f"配置的站点数量: {len(sites)}")

    if site:
        if site in sites:
            logger.info(f"站点 {site} 配置:")
            site_config = sites[site]
            for key, value in site_config.items():
                if key == 'cookie':
                    logger.info(f"  {key}: [HIDDEN]")
                else:
                    logger.info(f"  {key}: {value}")
        else:
            logger.error(f"站点 {site} 未找到")
    else:
        logger.info("所有站点:")
        for site_name in sites.keys():
            logger.info(f"  - {site_name}")


# ==================== 便捷函数 ====================

def run_signin(
    config_file: str = 'config.yml',
    force: bool = False,
    site: str | None = None
) -> dict:
    """
    便捷的签到执行函数，供外部脚本调用

    Args:
        config_file: 配置文件路径
        force: 是否强制重新签到
        site: 指定站点名称

    Returns:
        dict: 包含执行结果的字典
    """
    # 设置日志级别为INFO，不输出DEBUG信息
    logger.remove()
    logger.add(lambda msg: print(msg, end=''), level="INFO")

    try:
        # 初始化配置管理器
        config_manager = ConfigManager(config_file)

        # 创建调度器
        from .core.scheduler import TaskScheduler
        scheduler = TaskScheduler(config_manager)

        # 设置强制选项
        force_options = {}
        if force:
            force_options['force_all'] = True
        if site:
            force_options['force_site'] = site

        # 执行签到
        scheduler.run_once(force_options)

        # 获取结果
        from .core.signin_status import SignInStatusManager
        status_manager = SignInStatusManager()
        summary = status_manager.get_today_summary()

        return {
            'success': True,
            'summary': summary,
            'error': None
        }

    except Exception as e:
        logger.error(f"签到执行失败: {e}")
        return {
            'success': False,
            'summary': None,
            'error': str(e)
        }


def get_notification_message(include_details: bool = False) -> dict:
    """
    获取通知消息的便捷函数

    Args:
        include_details: 是否包含详细信息（默认False，仅显示基本状态）

    Returns:
        dict: 包含通知信息的字典
    """
    try:
        from .core.signin_status import SignInStatusManager

        status_manager = SignInStatusManager()
        summary = status_manager.get_today_summary()

        if summary['total'] == 0:
            return {
                'has_data': False,
                'title': '',
                'content': '',
                'summary': summary
            }

        # 构建通知内容
        success_sites = []
        failed_sites = []

        for site_name, site_info in summary['sites'].items():
            if site_info['status'] == 'success':
                result_msg = site_info.get('result', '成功')
                site_line = f"✅ {site_name}: {result_msg}"

                # 如果需要详细信息，添加消息和详情
                if include_details:
                    messages = site_info.get('messages', '')
                    details = site_info.get('details', '')

                    if messages:
                        site_line += f"\n    📨 消息: {messages[:100]}..."

                    if details:
                        # 处理详情信息，提取关键信息
                        if isinstance(details, dict):
                            detail_parts = []
                            if details.get('points'):
                                detail_parts.append(f"魔力值: {details['points']}")
                            if details.get('share_ratio'):
                                detail_parts.append(f"分享率: {details['share_ratio']}")
                            if details.get('uploaded'):
                                detail_parts.append(f"上传: {details['uploaded']}")
                            if details.get('downloaded'):
                                detail_parts.append(f"下载: {details['downloaded']}")
                            if detail_parts:
                                site_line += f"\n    📈 详情: {' | '.join(detail_parts)}"
                        else:
                            details_str = str(details)[:100]
                            site_line += f"\n    📈 详情: {details_str}..."

                success_sites.append(site_line)
            else:
                reason = site_info.get('reason', '失败')
                site_line = f"❌ {site_name}: {reason}"

                # 失败站点也可以显示详细的失败原因
                if include_details and len(reason) > 50:
                    # 如果失败原因很长，在详细模式下显示完整信息
                    site_line = f"❌ {site_name}: {reason[:50]}...\n    详细原因: {reason}"

                failed_sites.append(site_line)

        # 生成标题
        if summary['failed'] == 0:
            title = f"PT签到成功 ({summary['success']}/{summary['total']})"
        else:
            title = f"PT签到完成 ({summary['success']}/{summary['total']})"

        # 生成完整内容
        content_lines = [
            "PT站点签到完成",
            "",
            "📊 结果统计:",
            f"• 总计: {summary['total']} 个站点",
            f"• 成功: {summary['success']} 个",
            f"• 失败: {summary['failed']} 个"
        ]

        if success_sites:
            content_lines.extend(["", "✅ 成功站点:"] + success_sites)

        if failed_sites:
            content_lines.extend(["", "❌ 失败站点:"] + failed_sites)

        content = "\n".join(content_lines)

        return {
            'has_data': True,
            'title': title,
            'content': content,
            'summary': summary
        }

    except Exception as e:
        logger.error(f"获取通知消息失败: {e}")
        return {
            'has_data': False,
            'title': '',
            'content': '',
            'summary': None,
            'error': str(e)
        }


def main():
    """主入口函数"""
    cli()


if __name__ == '__main__':
    main()



from __future__ import annotations

from PIL import ImageChops, Image

RGB_BLACK = (0, 0, 0)


def compare_images_sort(image1: Image.Image, image2: Image.Image):
    if image1.size != image2.size:
        return False
    point1 = get_split_point(image1)
    point2 = get_split_point(image2)
    return bool(point1 and point1 == point2)


def check_analysis(image: Image.Image):
    if not image:
        return False
    width, height = image.size

    pixel_points = [(0, height - 1), (1, height - 2), (width - 1, 0), (width - 2, 1), (width - 1, height - 1),
                    (width - 2, height - 2)]
    for point in pixel_points:
        if image.getpixel(point) == RGB_BLACK:
            return True
    return False


def remove_date_string(image: Image.Image):
    width, height = image.size
    p = Image.new('RGB', (276, 15), (0, 0, 0))
    image.paste(p, (2, height - 32))


def compare_images(image_a: Image.Image, image_b: Image.Image) -> tuple[Image.Image, Image.Image, Image.Image] | None:
    a_width, a_height = image_a.size
    image_a_compare = image_a.crop((0, 0, a_width, a_height - 45))
    b_width, b_height = image_b.size
    image_b_compare = image_b.crop((0, 0, b_width, b_height - 45))

    diff = ImageChops.difference(image_a_compare, image_b_compare)
    if diff.getbbox() is None:
        return None
    return image_a, image_b, diff


def get_split_point(image: Image.Image) -> tuple | None:
    width, height = image.size
    blank_in_bottom_left = image.getpixel((0, height - 1)) == image.getpixel((1, height - 2)) == RGB_BLACK
    blank_in_top_right = image.getpixel((width - 1, 0)) == image.getpixel((width - 2, 1)) == RGB_BLACK

    x = 0
    y = 0
    if blank_in_bottom_left:
        for w in range(1, width):
            r, g, b = image.getpixel((w, height - 1))
            if r > 7 or g > 7 or b > 7:
                x += w
                break
    elif blank_in_top_right:
        for h in range(1, height):
            r, g, b = image.getpixel((width - 1, h))
            if r > 7 or g > 7 or b > 7:
                y += h
                break
    return (x, y) if x > 100 or y > 100 else None


def split_image(image: Image.Image) -> tuple:
    width, height = image.size
    x, y = get_split_point(image)
    if x > 0:
        a1 = image.crop((0, 0, x, height))
        a2 = image.crop((x, 0, width, height))
    else:
        a1 = image.crop((0, 0, width, y))
        a2 = image.crop((0, y, width, height))
    return a1, a2



from __future__ import annotations

import ast
import json
from typing import Final
from urllib.parse import urljoin

from requests import Response

from ..core.entry import SignInEntry
from ..base.request import check_network_state, NetworkState
from ..base.sign_in import check_final_state, SignState, Work
from ..schema.private_torrent import PrivateTorrent
from ..utils import net_utils
from ..utils.net_utils import get_module_name


class MainClass(PrivateTorrent):
    URL: Final = 'https://milkie.cc/'

    @classmethod
    def sign_in_build_schema(cls) -> dict:
        return {
            get_module_name(cls): {
                'type': 'object',
                'properties': {
                    'login': {
                        'type': 'object',
                        'properties': {
                            'username': {'type': 'string'},
                            'password': {'type': 'string'},
                        },
                        'additionalProperties': False,
                    },
                },
                'additionalProperties': False,
            },
        }

    def sign_in_build_login_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/api/v1/auth/sessions',
                method=self.sign_in_by_login,
                succeed_regex=['{"token":".*"}'],
                assert_state=(check_final_state, SignState.SUCCEED),
                is_base_content=True,
                response_urls=['/api/v1/auth/sessions'],
            )
        ]

    def sign_in_by_login(self, entry: SignInEntry, config: dict, work: Work, last_content: str) -> Response | None:
        if not (login := entry['site_config'].get('login')):
            entry.fail_with_prefix('Login data not found!')
            return None
        data = {
            'email': login['username'],
            'password': login['password'],
        }
        login_response = self.request(entry, 'post', work.url, data=data)
        self.session.headers.update({'authorization': 'Bearer ' + ast.literal_eval(login_response.text)['token']})
        return login_response

    def get_details(self, entry: SignInEntry, config: dict) -> None:
        link = urljoin(entry['url'], '/api/v1/auth')
        detail_response = self.request(entry, 'get', link)
        network_state = check_network_state(entry, link, detail_response)
        if network_state != NetworkState.SUCCEED:
            return
        detail_content = net_utils.decode(detail_response)
        data = json.loads(detail_content)
        entry['details'] = {
            'uploaded': str(data['user']['uploaded']) + 'B',
            'downloaded': str(data['user']['downloaded']) + 'B',
            'share_ratio': data['user']['uploaded'] / data['user']['downloaded'] if data['user']['downloaded'] else 0,
            'points': '*',
            'join_date': data['user']['createdAt'].split('T')[0],
            'seeding': '*',
            'leeching': '*',
            'hr': '*'
        }



from typing import Final
from urllib.parse import urljoin

from ..core.entry import SignInEntry
# Removed reseed functionality
from ..base.work import Work
from ..schema.nexusphp import Visit
from ..utils.value_handler import size


class MainClass(Visit):
    URL: Final = 'https://leaves.red/'
    USER_CLASSES: Final = {
        'downloaded': [size(750, 'GiB'), size(3, 'TiB')],
        'share_ratio': [3.05, 4.55],
        'days': [280, 700]
    }

    def sign_in_build_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        entry['extra_msg'] = f' 未签到: {urljoin(self.URL, "/attendance_new.php")}'
        return super().sign_in_build_workflow(entry, config)



import re
from typing import Final

from ..core.entry import SignInEntry
from ..base.sign_in import SignState
from ..base.sign_in import check_final_state
from ..base.work import Work
from ..schema.luminance import Luminance


class MainClass(Luminance):
    URL: Final = 'https://femdomcult.org/'
    USER_CLASSES: Final = {
        'downloaded': [5497558138880],
        'share_ratio': [1.05],
        'days': [56]
    }

    def sign_in_build_login_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/login',
                method=self.sign_in_by_get,
            ),
            Work(
                url='/login',
                method=self.sign_in_by_login,
                succeed_regex=['Logout'],
                assert_state=(check_final_state, SignState.SUCCEED),
                is_base_content=True,
                response_urls=['/index.php', '/']
            )
        ]

    def sign_in_build_login_data(self, login: dict, last_content: str) -> dict:
        print(last_content)
        return {
            'username': login['username'],
            'password': login['password'],
            'token': re.search(r'token" value="(.*?)"', last_content).group(1),
            'cinfo': '2048|1152|24|-480',
            'submit': 'Login'
        }



from typing import Final

# Removed reseed functionality
from ..schema.nexusphp import Visit


class MainClass(Visit):
    URL: Final = 'https://et8.org/'
    USER_CLASSES: Final = {
        'downloaded': [1099511627776, 8796093022208],
        'share_ratio': [3.05, 4.55],
        'days': [266, 616]
    }



from typing import Final

from ..core.entry import SignInEntry
from ..base.sign_in import check_final_state, SignState, Work
from ..schema.unit3d import Unit3D


class MainClass(Unit3D):
    URL: Final = 'https://jptv.club/'
    USER_CLASSES: Final = {
        'uploaded': [109951162777600],
        'days': [365]
    }

    def sign_in_build_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/',
                method=self.sign_in_by_get,
                succeed_regex=['<title>JPTV\\.club - JPTV for everyone!</title>'],
                assert_state=(check_final_state, SignState.SUCCEED),
                is_base_content=True
            )
        ]

    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        return selector



"""
签到状态管理器
记录每日签到状态，避免重复签到
"""
import json
import pathlib
from datetime import datetime
from typing import Dict, Any, Optional

from loguru import logger


class SignInStatusManager:
    """签到状态管理器"""
    
    def __init__(self, status_file: str = 'signin_status.json'):
        self.status_file = pathlib.Path(status_file)
        self.status_data: Dict[str, Any] = {}
        self.load_status()
    
    def load_status(self) -> None:
        """加载签到状态"""
        if self.status_file.exists():
            try:
                with open(self.status_file, 'r', encoding='utf-8') as f:
                    self.status_data = json.load(f)
                logger.debug(f"签到状态加载成功: {self.status_file}")
            except (json.JSONDecodeError, FileNotFoundError) as e:
                logger.warning(f"加载签到状态失败: {e}")
                self.status_data = {}
        else:
            self.status_data = {}
    
    def save_status(self) -> None:
        """保存签到状态"""
        try:
            with open(self.status_file, 'w', encoding='utf-8') as f:
                json.dump(self.status_data, f, ensure_ascii=False, indent=2)
            logger.debug(f"签到状态保存成功: {self.status_file}")
        except Exception as e:
            logger.error(f"保存签到状态失败: {e}")
    
    def get_today_key(self) -> str:
        """获取今日日期键"""
        return datetime.now().strftime('%Y-%m-%d')
    
    def is_signed_today(self, site_name: str) -> bool:
        """检查今日是否已签到"""
        today = self.get_today_key()
        return (
            today in self.status_data and
            site_name in self.status_data[today] and
            self.status_data[today][site_name].get('status') == 'success'
        )
    
    def get_site_status(self, site_name: str) -> Optional[Dict[str, Any]]:
        """获取站点今日状态"""
        today = self.get_today_key()
        if today in self.status_data and site_name in self.status_data[today]:
            return self.status_data[today][site_name]
        return None
    
    def record_signin_success(self, site_name: str, result: str, messages: str = '', details: str = '') -> None:
        """记录签到成功"""
        today = self.get_today_key()
        if today not in self.status_data:
            self.status_data[today] = {}

        self.status_data[today][site_name] = {
            'status': 'success',
            'result': result,
            'messages': messages,
            'details': details,
            'time': datetime.now().strftime('%H:%M:%S'),
            'timestamp': datetime.now().isoformat(),
            'failed_count': 0  # 成功后重置失败次数
        }
        self.save_status()
        logger.debug(f"记录签到成功: {site_name}")
    
    def record_signin_failed(self, site_name: str, reason: str) -> None:
        """记录签到失败"""
        today = self.get_today_key()
        if today not in self.status_data:
            self.status_data[today] = {}

        # 获取当前失败次数
        current_failed_count = 0
        if site_name in self.status_data[today]:
            current_failed_count = self.status_data[today][site_name].get('failed_count', 0)
            # 如果当前状态是成功，重置失败次数
            if self.status_data[today][site_name].get('status') == 'success':
                current_failed_count = 0

        self.status_data[today][site_name] = {
            'status': 'failed',
            'reason': reason,
            'time': datetime.now().strftime('%H:%M:%S'),
            'timestamp': datetime.now().isoformat(),
            'failed_count': current_failed_count + 1
        }
        self.save_status()
        logger.debug(f"记录签到失败: {site_name} - {reason} (失败次数: {current_failed_count + 1})")
    
    def clear_site_status(self, site_name: str, keep_failed_count: bool = False) -> None:
        """清除站点今日状态（用于强制重新签到）"""
        today = self.get_today_key()
        if today in self.status_data and site_name in self.status_data[today]:
            if keep_failed_count:
                # 保留失败次数
                failed_count = self.status_data[today][site_name].get('failed_count', 0)
                del self.status_data[today][site_name]
                # 如果有失败次数，创建一个新的记录保留失败次数
                if failed_count > 0:
                    self.status_data[today][site_name] = {
                        'failed_count': failed_count
                    }
            else:
                del self.status_data[today][site_name]
            self.save_status()
            logger.debug(f"清除站点状态: {site_name} (保留失败次数: {keep_failed_count})")

    def get_failed_count(self, site_name: str) -> int:
        """获取站点今日失败次数"""
        today = self.get_today_key()
        if today in self.status_data and site_name in self.status_data[today]:
            return self.status_data[today][site_name].get('failed_count', 0)
        return 0

    def should_skip_due_to_failures(self, site_name: str, max_failed_attempts: int, retry_interval_hours: int = 2) -> tuple[bool, str]:
        """检查是否应该因为失败次数过多而跳过站点"""
        failed_count = self.get_failed_count(site_name)

        if failed_count < max_failed_attempts:
            return False, ""

        # 检查最后失败时间
        site_status = self.get_site_status(site_name)
        if site_status and site_status.get('status') == 'failed':
            try:
                last_failed_time = datetime.fromisoformat(site_status['timestamp'])
                time_since_failure = datetime.now() - last_failed_time
                hours_since_failure = time_since_failure.total_seconds() / 3600

                if hours_since_failure < retry_interval_hours:
                    return True, f"连续失败{failed_count}次，{retry_interval_hours}小时内不再尝试"
                else:
                    # 超过重试间隔，可以重新尝试
                    return False, ""
            except (ValueError, KeyError):
                # 时间解析失败，允许重试
                return False, ""

        return True, f"连续失败{failed_count}次，暂时跳过"

    def reset_failed_count(self, site_name: str) -> None:
        """重置站点失败次数"""
        today = self.get_today_key()
        if today in self.status_data and site_name in self.status_data[today]:
            self.status_data[today][site_name]['failed_count'] = 0
            self.save_status()
            logger.info(f"重置站点失败次数: {site_name}")
    
    def clear_all_status(self) -> None:
        """清除今日所有状态（用于强制重新签到所有站点）"""
        today = self.get_today_key()
        if today in self.status_data:
            del self.status_data[today]
            self.save_status()
            logger.debug("清除今日所有签到状态")
    
    def get_today_summary(self) -> Dict[str, Any]:
        """获取今日签到摘要"""
        today = self.get_today_key()
        if today not in self.status_data:
            return {'total': 0, 'success': 0, 'failed': 0, 'sites': {}}
        
        sites_data = self.status_data[today]
        success_count = sum(1 for site in sites_data.values() if site.get('status') == 'success')
        failed_count = sum(1 for site in sites_data.values() if site.get('status') == 'failed')
        
        return {
            'total': len(sites_data),
            'success': success_count,
            'failed': failed_count,
            'sites': sites_data
        }
    
    def cleanup_old_records(self, keep_days: int = 7) -> None:
        """清理旧记录"""
        if not self.status_data:
            return
        
        today = datetime.now()
        keys_to_remove = []
        
        for date_key in self.status_data.keys():
            try:
                record_date = datetime.strptime(date_key, '%Y-%m-%d')
                days_diff = (today - record_date).days
                if days_diff > keep_days:
                    keys_to_remove.append(date_key)
            except ValueError:
                # 无效的日期格式，也删除
                keys_to_remove.append(date_key)
        
        for key in keys_to_remove:
            del self.status_data[key]
        
        if keys_to_remove:
            self.save_status()
            logger.info(f"清理了 {len(keys_to_remove)} 天的旧签到记录")



from __future__ import annotations

from typing import Final

from requests import Response

from ..core.entry import SignInEntry
# Removed reseed functionality
from ..base.sign_in import check_sign_in_state, check_final_state, SignState
from ..base.work import Work
from ..schema.nexusphp import Attendance
from ..utils import net_utils


class MainClass(Attendance):
    URL: Final = 'https://club.hares.top/'
    USER_CLASSES: Final = {
        'downloaded': [8796093022208],
        'share_ratio': [5.5],
        'days': [364]
    }

    def sign_in_build_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/',
                method=self.sign_in_by_get,
                succeed_regex=['已签到'],
                assert_state=(check_sign_in_state, SignState.NO_SIGN_IN),
                is_base_content=True,
            ),
            Work(
                url='/attendance.php?action=sign',
                method=self.sign_in_by_punch_in,
                succeed_regex=[
                    '签到成功',
                    '您今天已经签到过了'
                ],
                assert_state=(check_final_state, SignState.SUCCEED),
            ),
        ]

    def sign_in_by_punch_in(self, entry: SignInEntry, config: dict, work: Work, last_content: str) -> Response | None:
        return self.request(entry, 'get', work.url, headers={'accept': 'application/json'})

    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        net_utils.dict_merge(selector, {
            'detail_sources': {
                'default': {
                    'do_not_strip': True,
                    'link': '/userdetails.php?id={}',
                    'elements': {
                        'bar': 'ul.list-inline',
                        'table': 'div.layui-col-md10 > table:nth-child(1) > tbody'
                    }
                }
            },
            'details': {
                'points': {
                    'regex': '奶糖.(?:>.*?){4}([\\d,.]+)',
                    'handle': self.handle_points
                },
                'seeding': {
                    'regex': ('(做种中).*?(\\d+)', 2)
                },
                'leeching': {
                    'regex': ('(下载中).*?\\d+\\D+(\\d+)', 2)
                },
                'hr': None
            }
        })
        return selector

    def handle_points(self, value: str) -> str:
        return '0' if value in ['.'] else value



import re
from abc import ABC, abstractmethod
from datetime import date
from urllib.parse import urljoin

from dateutil.parser import parse
from bs4 import BeautifulSoup

from .private_torrent import PrivateTorrent
from ..core.entry import SignInEntry
from ..base.request import check_network_state, NetworkState
from ..base.sign_in import check_final_state, SignState, Work
from ..utils import net_utils


class XBTIT(PrivateTorrent, ABC):
    @property
    @abstractmethod
    def SUCCEED_REGEX(self) -> str:
        pass

    def sign_in_build_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/',
                method=self.sign_in_by_get,
                succeed_regex=[self.SUCCEED_REGEX],
                assert_state=(check_final_state, SignState.SUCCEED),
                is_base_content=True
            )
        ]

    @property
    def details_selector(self) -> dict:
        return {
            'user_id': r'usercp\.php\?uid=(\d+)',
            'detail_sources': {
                'default': {
                    'link': '/usercp.php?uid={}',
                    'elements': {
                        'bar': 'body > div.mainmenu > table:nth-child(5)',
                        'table': '#CurrentDetailsHideShowTR'
                    }
                }
            },
            'details': {
                'uploaded': {
                    'regex': r'↑.([\d,.]+ [ZEPTGMK]?iB)'
                },
                'downloaded': {
                    'regex': r'↓.([\d,.]+ [ZEPTGMK]?iB)'
                },
                'share_ratio': {
                    'regex': r'Ratio: ([\d.]+)'
                },
                'points': {
                    'regex': r'Bonus Points:.+?([\d,.]+)'
                },
                'join_date': {
                    'regex': r'Joined on.*?(\d{2}/\d{2}/\d{4})',
                    'handle': self.handle_join_date
                },
                'seeding': {
                    'regex': r'Seeding (\d+)'
                },
                'leeching': {
                    'regex': r'Leeching (\d+)'
                },
                'hr': None
            }
        }

    def get_XBTIT_message(self, entry: SignInEntry, config: dict,
                          MESSAGES_URL_REGEX: str = 'usercp\\.php\\?uid=\\d+&do=pm&action=list') -> None:
        if messages_url_match := re.search(MESSAGES_URL_REGEX, entry['base_content']):
            messages_url = messages_url_match.group()
        else:
            entry.fail_with_prefix('Can not found messages_url.')
            return
        messages_url = urljoin(entry['url'], messages_url)
        message_box_response = self.request(entry, 'get', messages_url)
        network_state = check_network_state(entry, messages_url, message_box_response)
        if network_state != NetworkState.SUCCEED:
            entry.fail_with_prefix(f'Can not read message box! url:{messages_url}')
            return

        message_elements = BeautifulSoup(net_utils.decode(message_box_response, "html.parser")).select(
            'tr > td.lista:nth-child(1)')
        unread_elements = filter(lambda elements: elements.get_text() == 'no', message_elements)
        failed = False
        for unread_element in unread_elements:
            td = unread_element.nextSibling.nextSibling.nextSibling.nextSibling.nextSibling.nextSibling
            title = td.text
            href = td.a.get('href')
            messages_url = urljoin(messages_url, href)
            message_response = self.request(entry, 'get', messages_url)
            network_state = check_network_state(entry, [messages_url], message_response)
            if network_state != NetworkState.SUCCEED:
                message_body = 'Can not read message body!'
                failed = True
            else:
                body_element = BeautifulSoup(net_utils.decode(message_response, "html.parser")).select_one(
                    '#PrivateMessageHideShowTR > td > table:nth-child(1) > tbody > tr:nth-child(2) > td')
                if body_element:
                    message_body = body_element.text.strip()
            entry['messages'] = entry['messages'] + (
                '\nTitle: {}\nLink: {}\n{}'.format(title, messages_url, message_body))
        if failed:
            entry.fail_with_prefix('Can not read message body!')

    def get_messages(self, entry: SignInEntry, config: dict) -> None:
        self.get_XBTIT_message(entry, config)

    def handle_join_date(self, value: str) -> date:
        return parse(value, dayfirst=True).date()



from typing import Final

# Removed reseed functionality
from ..schema.nexusphp import VisitHR
from ..utils.value_handler import size, handle_infinite


class MainClass(VisitHR):
    URL: Final = 'https://hhanclub.top/'
    USER_CLASSES: Final = {
        'downloaded': [size(750, 'GiB'), size(3, 'TiB')],
        'points': [900000, 1500000],
        'share_ratio': [3.05, 4.55],
        'days': [280, 700]
    }

    @property
    def details_selector(self) -> dict:
        return {
            'user_id': r'userdetails\.php\?id=(\d+)',
            'detail_sources': {
                'default': {
                    'link': '/userdetails.php?id={}',
                    'elements': {
                        'panel': '#user-info-panel',
                        'table': '#mainContent'
                    }
                }
            },
            'details': {
                'uploaded': {
                    'regex': r'上传量.+?([\d.]+ ?[ZEPTGMK]?i?B)'
                },
                'downloaded': {
                    'regex': r'下载量.+?([\d.]+ ?[ZEPTGMK]?i?B)'
                },
                'share_ratio': {
                    'regex': r'分享率.*?(---|∞|Inf\.|无限|無限|[\d,.]+)',
                    'handle': handle_infinite
                },
                'points': {
                    'regex': r'做种积分：.*?([\d,.]+)'
                },
                'join_date': {
                    'regex': r'加入日期.*?(\d{4}-\d{2}-\d{2})',
                },
                'seeding': {
                    'regex': (r'勋章.*?([\d,.]+).*?([\d,.]+)', 2)
                },
                'leeching': {
                    'regex': (r'勋章.*?([\d,.]+).*?([\d,.]+).*?([\d,.]+).*?([\d,.]+)', 4)
                },
                'hr': {
                    'regex': r'H&R.*?(\d+)'
                }
            }
        }

    # def sign_in_build_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
    #     return [
    #         Work(
    #             url='/attendance.php',
    #             method=self.sign_in_by_get,
    #             succeed_regex=[r'这是您的第\d+次签到，已连续签到\d+天，本次签到获得\d+个憨豆。'],
    #             assert_state=(check_final_state, SignState.SUCCEED),
    #             is_base_content=True
    #         )
    #     ]



"""
PT站点自动签到工具

一个独立的PT站点自动签到工具，支持多种站点类型和调度模式。
"""

__version__ = "0.2.0"
__author__ = "wuyaos"
__email__ = ""
__description__ = "PT站点自动签到工具 - 独立版本，移除FlexGet依赖"

# 导出主要类和函数
from .core.config_manager import ConfigManager
from .core.scheduler import TaskScheduler
from .core.signin_status import SignInStatusManager

__all__ = [
    "ConfigManager",
    "TaskScheduler",
    "SignInStatusManager",
    "__version__",
    "__author__",
    "__email__",
    "__description__",
]



from __future__ import annotations

from typing import Final
from urllib.parse import urljoin

from flexget.entry import Entry

from ..core.entry import SignInEntry
# Removed reseed functionality
from ..base.sign_in import SignState, check_final_state
from ..base.work import Work
from ..schema.gazelle import Gazelle
from ..utils import net_utils


class MainClass(Gazelle, Reseed):
    URL: Final = 'https://greatposterwall.com/'
    USER_CLASSES: Final = {
        'downloaded': [214748364800, 10995116277760],
        'share_ratio': [1.2, 1.2],
        'days': [14, 140]
    }

    @classmethod
    def sign_in_build_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/',
                method=self.sign_in_by_get,
                succeed_regex=[('class="HeaderProfile-name.*?">\n(.+?)</a>', 1)],
                assert_state=(check_final_state, SignState.SUCCEED),
                is_base_content=True
            )
        ]

    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        net_utils.dict_merge(selector, {
            'detail_sources': {
                'default': {
                    'elements': {
                        'table': 'div.SidebarItemStats.SidebarItem > ul',
                        'join_date': '#join-date-value'
                    }
                },
                'extend': {
                    'link': '/ajax.php?action=community_stats&userid={}'
                }
            },
            'details': {
                'points': None,
            }
        })
        return selector

    @classmethod
    


import json
from typing import Final
from urllib.parse import urljoin

from ..core.entry import SignInEntry
from ..base.request import NetworkState, check_network_state
from ..base.sign_in import SignState, check_final_state
from ..base.work import Work
from ..schema.private_torrent import PrivateTorrent
from ..utils import net_utils


class MainClass(PrivateTorrent):
    URL: Final = 'https://digitalcore.club/'
    USER_CLASSES: Final = {
        'uploaded': [1_288_490_188_800],
        'share_ratio': [1.1],
        'days': [210],
    }

    def sign_in_build_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/api/v1/status?timeSinceLastCheck=0',
                method=self.sign_in_by_get,
                succeed_regex=['user'],
                assert_state=(check_final_state, SignState.SUCCEED),
                is_base_content=True,
            ),
        ]

    def get_details(self, entry: SignInEntry, config: dict) -> None:
        link = urljoin(entry['url'],
                       '/api/v1/users/{}'.format(self.get_user_id(entry, '"id":(.+?),', entry['base_content'])))
        detail_response = self.request(entry, 'get', link)
        network_state = check_network_state(entry, link, detail_response)
        if network_state != NetworkState.SUCCEED:
            return
        detail_content = net_utils.decode(detail_response)
        data = json.loads(detail_content)
        data2 = json.loads(entry['base_content'])
        entry['details'] = {
            'uploaded': str(data['uploaded']) + 'B',
            'downloaded': str(data['downloaded']) + 'B',
            'share_ratio': data['uploaded'] / data['downloaded'],
            'points': data['bonuspoang'],
            'join_date': data['added'].split()[0],  # TODO: timezone not considered
            'seeding': '*',
            'leeching': '*',
            'hr': data2['user']['hnr'],
        }



from typing import Final

# Removed reseed functionality
from ..schema.xbtit import XBTIT
from ..utils import net_utils


class MainClass(XBTIT):
    URL: Final = 'https://hd-torrents.org/'
    SUCCEED_REGEX: Final = 'Welcome back, .+?!'
    USER_CLASSES: Final = {
        'uploaded': [1099511627776],
        'share_ratio': [4]
    }
    
    @property
    def details_selector(self) -> dict:
        selector = super().details_selector
        net_utils.dict_merge(selector, {
            'detail_sources': {
                'default': {
                    'elements': {
                        'bar': 'body > div.mainmenu > table:nth-child(4)',
                    }
                }
            }
        })
        return selector



import re
from typing import Final

from ..core.entry import SignInEntry
from ..base.sign_in import check_final_state, SignState, Work
from ..schema.private_torrent import PrivateTorrent
from ..utils.value_handler import handle_infinite


class MainClass(PrivateTorrent):
    URL: Final = 'https://scenetime.com/'
    USER_CLASSES: Final = {
        'uploaded': [32_212_254_720],
        'share_ratio': [1.05],
        'days': [28],
    }

    def sign_in_build_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/',
                method=self.sign_in_by_get,
                succeed_regex=['Logout'],
                assert_state=(check_final_state, SignState.SUCCEED),
                is_base_content=True,
            ),
        ]

    @property
    def details_selector(self) -> dict:
        return {
            'user_id': fr'''(?x)(?<= {re.escape('userdetails.php?id=')})
                                (. +?)
                                (?= ")''',
            'detail_sources': {
                'default': {
                    'link': '/userdetails.php?id={}',
                    'elements': {
                        'stats': 'div.startpage > table > tbody > tr > td > table.main',
                    }
                }
            },
            'details': {
                'uploaded': {
                    'regex': r'''(?x)(?<= Uploaded)
                                    ([\d.] +
                                    \ 
                                    [ZEPTGMKk] ? B)'''
                },
                'downloaded': {
                    'regex': r'''(?x)(?<= Downloaded)
                                    ([\d.] +
                                    \ 
                                    [ZEPTGMKk] ? B)'''
                },
                'share_ratio': {
                    'regex': r'''(?x)(?<= Share\ Ratio)
                                    (Inf. | [\d,.] +)''',
                    'handle': handle_infinite
                },
                'points': {
                    'regex': r'''(?x)(?<= Bonus\ Points)
                                    ([\d,.] +)'''
                },
                'join_date': {
                    'regex': r'''(?x)(?<= Join Date)
                                    (\d {4} - \d {2} - \d {2})''',
                },
                'seeding': {
                    'regex': r'''(?x)(?<= Seeding \s)
                                    ([\d,] +)'''
                },
                'leeching': {
                    'regex': r'''(?x)(?<= Leeching \s)
                                    ([\d,] +)'''
                },
                'hr': {
                    'regex': r'''(?x)(?<= Hit\ &\ Runs \s)
                                    ([\d,] +)'''
                },
            }
        }



import re
from abc import ABC

from .private_torrent import PrivateTorrent
from ..core.entry import SignInEntry
from ..base.request import NetworkState, check_network_state
from ..base.sign_in import SignState, check_final_state
from ..base.work import Work
from ..utils.net_utils import get_module_name
from ..utils.value_handler import handle_infinite, handle_join_date


class Luminance(PrivateTorrent, ABC):
    @classmethod
    def sign_in_build_schema(cls) -> dict:
        return {
            get_module_name(cls): {
                'type': 'object',
                'properties': {
                    'login': {
                        'type': 'object',
                        'properties': {
                            'username': {'type': 'string'},
                            'password': {'type': 'string'}
                        },
                        'additionalProperties': False
                    }
                },
                'additionalProperties': False
            }
        }

    def sign_in_build_login_workflow(self, entry: SignInEntry, config: dict) -> list[Work]:
        return [
            Work(
                url='/login',
                method=self.sign_in_by_get,
                assert_state=(check_network_state, NetworkState.SUCCEED),
            ),
            Work(
                url='/login',
                method=self.sign_in_by_login,
                succeed_regex=[r'''(?x)Logout | Kilpés'''],
                assert_state=(check_final_state, SignState.SUCCEED),
                is_base_content=True,
                response_urls=['/'],
            )
        ]

    @property
    def details_selector(self) -> dict:
        return {
            'user_id': fr'''(?x)(?<= {re.escape('user.php?id=')})
                                (. +?)
                                (?= ")''',
            'detail_sources': {
                'default': {
                    'do_not_strip': True,
                    'link': '/user.php?id={}',
                    'elements': {
                        'stats': '#content > div > div.sidebar > div:nth-child(4)',
                        'credits': '#bonusdiv > h4',
                        'connected': '#content > div > div.sidebar > div:nth-child(10)'
                    }
                }
            },
            'details': {
                'uploaded': {
                    'regex': r'''(?x)(?: Uploaded | Feltöltve):
                                    \ 
                                    ([\d.] +
                                    \ 
                                    [ZEPTGMK] ? i ? B)'''
                },
                'downloaded': {
                    'regex': r'''(?x)(?: Downloaded | Letöltve):
                                    \ 
                                    ([\d.] +
                                    \ 
                                    [ZEPTGMK] ? i ? B)'''
                },
                'share_ratio': {
                    'regex': r'''(?x)(?: Ratio | Arány):\ <. *?>
                                    (∞ | [\d,.] +)''',
                    'handle': handle_infinite
                },
                'points': {
                    'regex': r'''(?x)(?: Credits | Bónuszpontok):
                                    \s *
                                    ([\d,.] +)'''
                },
                'join_date': {
                    'regex': r'''(?x)(?: Joined | Regisztrált):
                                    . *?
                                    title="
                                    ((\w + \ ) {2}
                                    \w +)''',
                    'handle': handle_join_date
                },
                'seeding': {
                    'regex': r'''(?x)(?<= Seeding:\ )
                                    ([\d,] +)'''
                },
                'leeching': {
                    'regex': r'''(?x)(?<= Leeching:\ )
                                    ([\d,] +)'''
                },
                'hr': None
            }
        }
